{
  "nbformat": 4,
  "nbformat_minor": 0,
  "metadata": {
    "colab": {
      "name": "CSC413 Tutorial: Optimization",
      "provenance": [],
      "collapsed_sections": []
    },
    "kernelspec": {
      "name": "python3",
      "display_name": "Python 3"
    },
    "accelerator": "GPU"
  },
  "cells": [
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "9Q9b5-ME43WT"
      },
      "source": [
        "# How to Train Neural Networks\n",
        "\n",
        "**References**:\n",
        "\n",
        "* Notes and tutorials from other courses:\n",
        "  - [ECE521 (Winter 2017)](https://ece521.github.io/) tutorial on [Training neural network](http://www.psi.toronto.edu/~jimmy/ece521/Tut2.pdf)\n",
        "  - [Stanford's CS231n](https://cs231n.github.io/) notes on [Stochastic Gradient Descent](https://cs231n.github.io/optimization-1/), [Setting up data and loss](https://cs231n.github.io/neural-networks-2/), and [Training neural networks](https://cs231n.github.io/neural-networks-3/)\n",
        "  - [Deeplearning.ai's](https://www.deeplearning.ai/) interactive notes on [Initialization](https://www.deeplearning.ai/ai-notes/initialization/) and [Parameter optimization in neural networks](https://www.deeplearning.ai/ai-notes/optimization/) \n",
        "  - Jimmy Ba's Talk for [Optimization in Deep Learning](https://www.youtube.com/watch?v=eHEkbDHVDuI) at [Deep Learning Summer School 2019](https://dlrlsummerschool.ca/)\n",
        "* Academic/white papers:\n",
        "  - [SGD](https://www.microsoft.com/en-us/research/publication/stochastic-gradient-tricks/?from=http%3A%2F%2Fresearch.microsoft.com%2Fpubs%2F192769%2Ftricks-2012.pdf) tips and tricks from Leon Bottou\n",
        "  - [Efficient BackProp](http://yann.lecun.com/exdb/publis/pdf/lecun-98b.pdf) from Yann LeCun\n",
        "  - [Practical Recommendations for Gradient-Based Training of Deep Architectures](https://arxiv.org/pdf/1206.5533v2.pdf) from Yoshua Bengio"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "f6jL5jLvHQtB"
      },
      "source": [
        "## The Big Picture of Training Loop\n",
        "\n",
        "![Training Loop Diagram](https://drive.google.com/uc?id=1c79evEvqEwvgDbEO9-ZDwUArA2BK2_sC)\n",
        "\n",
        "The training loop consist of these steps:\n",
        "* Initialize the parameters $\\theta$ of your network\n",
        "* Loop until convergence:\n",
        "  - Sample batch of input/output pairs\n",
        "  - Compute forward propagation $h(x;\\theta)$ of the input with your model\n",
        "  - Compute the loss function $\\mathcal{L}(h(x; \\theta), y)$ \n",
        "  - Update the parameters in $\\theta$ using the optimizer\n",
        "\n",
        "We will discuss:\n",
        "1. **Initialization**: Xavier, He, Uniform, etc.\n",
        "2. **Optimizers**: SGD, Momentum, Nesterov Momentum, Adagrad, RMSProp, Adam\n",
        "3. **Hyperparameters tuning**: learning rate (initial & decay schedule), batch size"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "L95bz_EqD_yv"
      },
      "source": [
        "## Skeletal Training Code\n",
        "\n",
        "We first show a typical training loop code in PyTorch, based on the previous tutorial"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "4axBnxovhLaW"
      },
      "source": [
        "import torch\n",
        "import torch.nn as nn\n",
        "import numpy as np\n",
        "import matplotlib.pyplot as plt"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "41BqkXQzEiT7"
      },
      "source": [
        "Define the architecture. In this case, just an MLP"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "AZ7QmA_2E-SQ"
      },
      "source": [
        "class MLP(nn.Module):\n",
        "  def __init__(self, input_dim=784, num_hidden=300, output_dim=10, activation_func=torch.relu):\n",
        "    super(MLP, self).__init__()\n",
        "    self.fc1 = nn.Linear(input_dim, num_hidden)\n",
        "    self.fc2 = nn.Linear(num_hidden, num_hidden)\n",
        "    self.fc3 = nn.Linear(num_hidden, num_hidden)\n",
        "    self.fc4 = nn.Linear(num_hidden, output_dim)\n",
        "    self.activation_func = activation_func\n",
        "\n",
        "  def forward(self, x):\n",
        "    h1 = self.activation_func(self.fc1(x))\n",
        "    h2 = self.activation_func(self.fc2(h1))\n",
        "    h3 = self.activation_func(self.fc3(h2))\n",
        "    out = self.fc4(h3)\n",
        "    \n",
        "    return out, [h1, h2, h3]"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "aFsesDv6FF3S"
      },
      "source": [
        "Load the MNIST dataset for experiment (as from previous tutorial)"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "_kIcdc2bFJpC",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 493
        },
        "outputId": "d6b70190-7472-451b-da51-f4863c465c69"
      },
      "source": [
        "from torchvision import datasets, transforms\n",
        "\n",
        "mnist_train = datasets.MNIST('data', train=True, download=True,\n",
        "                       transform=transforms.ToTensor())\n",
        "\n",
        "mnist_test = datasets.MNIST('../data', train=False, download=True, transform=\n",
        "                            transforms.ToTensor())"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "stream",
          "text": [
            "  0%|          | 0/9912422 [00:00<?, ?it/s]"
          ],
          "name": "stderr"
        },
        {
          "output_type": "stream",
          "text": [
            "Downloading http://yann.lecun.com/exdb/mnist/train-images-idx3-ubyte.gz to data/MNIST/raw/train-images-idx3-ubyte.gz\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "stream",
          "text": [
            "9920512it [00:00, 21393209.73it/s]                            \n"
          ],
          "name": "stderr"
        },
        {
          "output_type": "stream",
          "text": [
            "Extracting data/MNIST/raw/train-images-idx3-ubyte.gz to data/MNIST/raw\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "stream",
          "text": [
            "32768it [00:00, 331930.04it/s]\n",
            "0it [00:00, ?it/s]"
          ],
          "name": "stderr"
        },
        {
          "output_type": "stream",
          "text": [
            "Downloading http://yann.lecun.com/exdb/mnist/train-labels-idx1-ubyte.gz to data/MNIST/raw/train-labels-idx1-ubyte.gz\n",
            "Extracting data/MNIST/raw/train-labels-idx1-ubyte.gz to data/MNIST/raw\n",
            "Downloading http://yann.lecun.com/exdb/mnist/t10k-images-idx3-ubyte.gz to data/MNIST/raw/t10k-images-idx3-ubyte.gz\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "stream",
          "text": [
            "1654784it [00:00, 4741275.01it/s]                          \n",
            "8192it [00:00, 132994.28it/s]\n"
          ],
          "name": "stderr"
        },
        {
          "output_type": "stream",
          "text": [
            "Extracting data/MNIST/raw/t10k-images-idx3-ubyte.gz to data/MNIST/raw\n",
            "Downloading http://yann.lecun.com/exdb/mnist/t10k-labels-idx1-ubyte.gz to data/MNIST/raw/t10k-labels-idx1-ubyte.gz\n",
            "Extracting data/MNIST/raw/t10k-labels-idx1-ubyte.gz to data/MNIST/raw\n",
            "Processing...\n",
            "Done!\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "stream",
          "text": [
            "  0%|          | 16384/9912422 [00:00<01:24, 116695.81it/s]"
          ],
          "name": "stderr"
        },
        {
          "output_type": "stream",
          "text": [
            "Downloading http://yann.lecun.com/exdb/mnist/train-images-idx3-ubyte.gz to ../data/MNIST/raw/train-images-idx3-ubyte.gz\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "stream",
          "text": [
            "9920512it [00:00, 24298779.54it/s]                           \n"
          ],
          "name": "stderr"
        },
        {
          "output_type": "stream",
          "text": [
            "Extracting ../data/MNIST/raw/train-images-idx3-ubyte.gz to ../data/MNIST/raw\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "stream",
          "text": [
            "32768it [00:00, 319512.53it/s]                           \n",
            "0it [00:00, ?it/s]"
          ],
          "name": "stderr"
        },
        {
          "output_type": "stream",
          "text": [
            "Downloading http://yann.lecun.com/exdb/mnist/train-labels-idx1-ubyte.gz to ../data/MNIST/raw/train-labels-idx1-ubyte.gz\n",
            "Extracting ../data/MNIST/raw/train-labels-idx1-ubyte.gz to ../data/MNIST/raw\n",
            "Downloading http://yann.lecun.com/exdb/mnist/t10k-images-idx3-ubyte.gz to ../data/MNIST/raw/t10k-images-idx3-ubyte.gz\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "stream",
          "text": [
            "1654784it [00:00, 5290340.23it/s]                           \n",
            "8192it [00:00, 132616.49it/s]\n"
          ],
          "name": "stderr"
        },
        {
          "output_type": "stream",
          "text": [
            "Extracting ../data/MNIST/raw/t10k-images-idx3-ubyte.gz to ../data/MNIST/raw\n",
            "Downloading http://yann.lecun.com/exdb/mnist/t10k-labels-idx1-ubyte.gz to ../data/MNIST/raw/t10k-labels-idx1-ubyte.gz\n",
            "Extracting ../data/MNIST/raw/t10k-labels-idx1-ubyte.gz to ../data/MNIST/raw\n",
            "Processing...\n",
            "Done!\n"
          ],
          "name": "stdout"
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "Mx4NUjQHFPZb",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 503
        },
        "outputId": "7764c0a3-2fac-4e88-f03e-bdc7bb7728eb"
      },
      "source": [
        "from torch.utils.data import DataLoader\n",
        "import torchvision\n",
        "\n",
        "mnist_train = datasets.MNIST('data', train=True, download=True,\n",
        "                       transform = torchvision.transforms.Compose([\n",
        "                        torchvision.transforms.ToTensor(),\n",
        "                        torchvision.transforms.Normalize((0.1307,),(0.3081,)),\n",
        "                    ]))\n",
        "\n",
        "mnist_test = datasets.MNIST('data', train=False, download=True, \n",
        "                            transform = torchvision.transforms.Compose([\n",
        "                        torchvision.transforms.ToTensor(),\n",
        "                        torchvision.transforms.Normalize((0.1307,),(0.3081,)),\n",
        "                    ]))\n",
        "\n",
        "bs = 128\n",
        "train_dl = DataLoader(mnist_train, batch_size=bs)\n",
        "test_dl = DataLoader(mnist_test, batch_size = 100)\n",
        "\n",
        "dataiter = iter(train_dl)\n",
        "images, labels = dataiter.next()\n",
        "viz = torchvision.utils.make_grid(images, nrow=10, padding = 2).numpy()\n",
        "fig, ax = plt.subplots(figsize= (8,8))\n",
        "ax.imshow(np.transpose(viz, (1,2,0)))\n",
        "ax.grid(None)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "stream",
          "text": [
            "Clipping input data to the valid range for imshow with RGB data ([0..1] for floats or [0..255] for integers).\n"
          ],
          "name": "stderr"
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAX8AAAHVCAYAAAAZw/vvAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n4TRA/j/tNHukjbFDnQAAAABJRU5ErkJggg==\n",
            "text/plain": [
              "<Figure size 576x576 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "xgm6i8ZoCTjN"
      },
      "source": [
        "def train_model(model, optimizer, train_loader, test_loader, epochs=100, print_every=10, debug=False):\n",
        "  if debug:\n",
        "    # Visualize the initial weights  \n",
        "    weights_list = []\n",
        "    for i, module in enumerate(model.modules()):\n",
        "      if isinstance(module, nn.Linear):\n",
        "        weights = module.weight\n",
        "        weights = weights.reshape(-1).detach().cpu().numpy()\n",
        "        weights_list.append(weights)\n",
        "    \n",
        "    num_weight_layers = len(weights_list)\n",
        "    fig, ax = plt.subplots(nrows=1, ncols=num_weight_layers, figsize=(5*num_weight_layers,5))\n",
        "    for i in range(num_weight_layers):\n",
        "      plt.subplot(1,num_weight_layers, i+1)\n",
        "      plt.hist(weights_list[i])\n",
        "      plt.title(\"Init Weights (Layer {}-{})\".format(i, i+1))\n",
        "    plt.show()\n",
        "\n",
        "  # optimizer = torch.optim.Adam(model.parameters(), lr=0.01)\n",
        "  criterion = nn.CrossEntropyLoss()\n",
        "  train_accs = []\n",
        "  test_accs = []\n",
        "  train_losses = []\n",
        "  test_losses = []\n",
        "  \n",
        "  # Using GPUs in PyTorch is pretty straightforward\n",
        "  if torch.cuda.is_available():\n",
        "      print(\"Using cuda\")\n",
        "      use_cuda = True\n",
        "      device = torch.device(\"cuda\")\n",
        "  else:\n",
        "      device = \"cpu\"\n",
        "  \n",
        "  # Move the model to GPU, if available\n",
        "  model.to(device)    \n",
        "  model.train()\n",
        "  \n",
        "  for epoch in range(epochs):\n",
        "    xentropy_loss_avg = 0.\n",
        "    correct = 0.\n",
        "    total = 0.\n",
        "\n",
        "    for i, (inputs, labels) in enumerate(train_loader): \n",
        "      model.zero_grad()\n",
        "      inputs = inputs.to(device)\n",
        "      labels = labels.to(device)\n",
        "      inputs = inputs.view(inputs.size(0), -1) # Flatten input from [batch_size, 1, 28, 28] to [batch_size, 784]\n",
        "      pred, activations = model(inputs)\n",
        "      xentropy_loss = criterion(pred, labels)\n",
        "      xentropy_loss.backward()\n",
        "\n",
        "      optimizer.step()\n",
        "\n",
        "      if debug and epoch == 0 and i == 0:\n",
        "        # Inspect gradients\n",
        "        grad_list = []\n",
        "        for layer_index, param in enumerate(model.parameters()):\n",
        "          if layer_index % 2 == 0:\n",
        "            # These are the weights (not biases)\n",
        "            grad = param.grad.reshape(-1).detach().cpu().numpy()\n",
        "            grad_list.append(grad)\n",
        "\n",
        "        plot_grad_histograms(grad_list, epoch, init=True)\n",
        "\n",
        "        # Plot activation\n",
        "        act_list = []\n",
        "        for act in activations:\n",
        "          act = act.reshape(-1).detach().cpu().numpy()\n",
        "          act_list.append(act)\n",
        "        \n",
        "        plot_act_histograms(act_list, epoch, init=True)\n",
        "\n",
        "      xentropy_loss_avg += xentropy_loss.item()\n",
        "\n",
        "      # Calculate running average of accuracy\n",
        "      pred = torch.max(pred.data, 1)[1]\n",
        "      total += labels.size(0)\n",
        "      correct += (pred == labels.data).sum().item()\n",
        "    accuracy = correct / total\n",
        "\n",
        "    test_acc, test_loss = evaluate(model, test_loader, criterion, device)\n",
        "    if epoch % print_every == 0:\n",
        "      print(\"Epoch {}, Train acc: {:.2f}%, Test acc: {:.2f}%\".format(epoch, accuracy*100, test_acc*100))\n",
        "\n",
        "      if debug:\n",
        "        # Inspect gradients\n",
        "        grad_list = []\n",
        "        for layer_index, param in enumerate(model.parameters()):\n",
        "          if layer_index % 2 == 0:\n",
        "            # These are the weights (not biases)\n",
        "            grad = param.grad.reshape(-1).detach().cpu().numpy()\n",
        "            grad_list.append(grad)\n",
        "        plot_grad_histograms(grad_list, epoch)\n",
        "\n",
        "        # Plot activation\n",
        "        act_list = []\n",
        "        for act in activations:\n",
        "          act = act.reshape(-1).detach().cpu().numpy()\n",
        "          act_list.append(act)\n",
        "        plot_act_histograms(act_list, epoch)\n",
        "\n",
        "    train_accs.append(accuracy)\n",
        "    test_accs.append(test_acc)\n",
        "    train_losses.append(xentropy_loss_avg/i)\n",
        "    test_losses.append(test_loss)\n",
        "\n",
        "  return train_accs, test_accs, train_losses, test_losses\n",
        "\n",
        "def evaluate(model, loader, criterion, device):\n",
        "  model.eval()    # Change model to 'eval' mode (BN uses moving mean/var).\n",
        "  correct = 0.\n",
        "  total = 0.\n",
        "  val_loss = 0.\n",
        "  for i, (inputs, labels) in enumerate(loader):\n",
        "    with torch.no_grad():\n",
        "      inputs = inputs.to(device)\n",
        "      labels = labels.to(device)\n",
        "      inputs = inputs.view(inputs.size(0), -1) \n",
        "      pred, activations = model(inputs)\n",
        "      xentropy_loss = criterion(pred, labels)\n",
        "      val_loss += xentropy_loss.item()\n",
        "\n",
        "    pred = torch.max(pred.data, 1)[1]\n",
        "    total += labels.size(0)\n",
        "    correct += (pred == labels).sum().item()\n",
        "\n",
        "  val_acc = correct / total\n",
        "  val_loss = val_loss / i \n",
        "  model.train()\n",
        "  return val_acc, val_loss\n",
        "  \n",
        "def plot_grad_histograms(grad_list, epoch, init=False):\n",
        "  fig, ax = plt.subplots(nrows=1, ncols=len(grad_list), figsize=(5*len(grad_list),5))\n",
        "  for i, grad in enumerate(grad_list):\n",
        "    plt.subplot(1,len(grad_list), i+1)\n",
        "    plt.hist(grad)\n",
        "    if init:\n",
        "      plt.title(\"Grads for Weights (Layer {}-{}) Init\".format(i, i+1))\n",
        "    else:\n",
        "      plt.title(\"Grads for Weights (Layer {}-{}) Epoch {}\".format(i, i+1, epoch))\n",
        "  plt.show()\n",
        "\n",
        "def plot_act_histograms(act_list, epoch, init=False):\n",
        "  fig, ax = plt.subplots(nrows=1, ncols=len(act_list), figsize=(5*len(act_list),5))\n",
        "  for i, act in enumerate(act_list):\n",
        "    plt.subplot(1,len(act_list), i+1)\n",
        "    plt.hist(act)\n",
        "    if init:\n",
        "      plt.title(\"Activations for Layer {} Init\".format(i+1))\n",
        "    else:\n",
        "      plt.title(\"Activations for Layer {} Epoch {}\".format(i+1, epoch))\n",
        "  plt.show()\n"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "sJ87cv7vQUiU"
      },
      "source": [
        "def plot_acc_loss(train_accs, test_accs, train_losses, test_losses, caption):\n",
        "  # Visualize the loss / acc\n",
        "  plt.plot(train_accs, label=\"Train\")\n",
        "  plt.plot(test_accs, label=\"Test\")\n",
        "  plt.xlabel(\"Epoch\")\n",
        "  plt.ylabel(\"Accuracy\")\n",
        "  plt.legend()\n",
        "  plt.title(\"Classification Accuracy vs Epoch: {}\".format(caption))\n",
        "\n",
        "\n",
        "  # Visualize the loss / acc\n",
        "  plt.figure()\n",
        "  plt.plot(train_losses, label=\"Train\")\n",
        "  plt.plot(test_losses, label=\"Test\")\n",
        "  plt.xlabel(\"Epoch\")\n",
        "  plt.ylabel(\"Cross Entropy Loss\")\n",
        "  plt.legend()\n",
        "  plt.title(\"Cross Entropy Loss vs Epoch: {}\".format(caption))\n",
        "\n",
        "  return "
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "KZ27LqBXF3YF"
      },
      "source": [
        "## 1. Initialization\n"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "GdmgvNCNWDW-"
      },
      "source": [
        "We implement different types of initializations:\n",
        "1. Zero (constant)\n",
        "2. Uniform Init: $\\mathcal{U}(0,1)$\n",
        "3. Xavier Init:  $\\mathcal{N}(0, 1/n^{l-1})$\n",
        "3. He Init: \\mathcal{N}(0, 2/n^{l-1})"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "Km32xUETYIZ2"
      },
      "source": [
        "See different types of initializations: https://pytorch.org/docs/stable/nn.init.html "
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "Vuu4BUhuF5yW"
      },
      "source": [
        "def init_weights_zero(m):\n",
        "  if type(m) == nn.Linear:\n",
        "    m.weight.data.fill_(0.0)\n",
        "    m.bias.data.fill_(0.0)\n",
        "\n",
        "def init_weights_uniform(m):\n",
        "  if type(m) == nn.Linear:\n",
        "    m.weight.data.uniform_(0.0, 1.0)\n",
        "    m.bias.data.fill_(0.0)\n",
        "\n",
        "def init_weights_xavier(m):\n",
        "  if type(m) == nn.Linear:\n",
        "    # w ~ N(0, 1)*sqrt(1/(fan_in))\n",
        "    # w ~ N(0, 1)*sqrt(2/(fan_in + fan_out)))\n",
        "    # torch.nn.init.xavier_normal_(m.weight, gain=1.0)\n",
        "    n = m.in_features\n",
        "    std = np.sqrt(1.0/n)\n",
        "    m.weight.data.normal_(0,std)\n",
        "    m.bias.data.fill_(0.0)\n",
        "\n",
        "def init_weights_kaiminghe(m):\n",
        "  if type(m) == nn.Linear:\n",
        "    # w ~ N(0, 1)*sqrt(1/(fan_in))\n",
        "    # torch.nn.init.kaiming_normal_(m.weight, a = 0)\n",
        "    n = m.in_features\n",
        "    std = np.sqrt(2.0/n)\n",
        "    m.weight.data.normal_(0,std)\n",
        "    m.bias.data.fill_(0.0)\n",
        "    \n",
        "def apply_initialization(model, initialization):\n",
        "  \"\"\" \n",
        "  Apply different types of initialization\n",
        "  \"\"\"\n",
        "  if initialization == 'zero':\n",
        "    model.apply(init_weights_zero)\n",
        "  elif initialization == 'uniform':\n",
        "    model.apply(init_weights_uniform)\n",
        "  elif initialization == 'xavier':\n",
        "    model.apply(init_weights_xavier)\n",
        "  elif initialization == 'he':\n",
        "    model.apply(init_weights_kaiminghe)\n",
        "  \n",
        "  return model"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "4W1ZgaLfGS_S"
      },
      "source": [
        "Let's try with our first initialization method: **zero** initialization. This sets all the weights and biases of the layers to zero. "
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "w2DuFTLiGCGq",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 119
        },
        "outputId": "b2e2125f-da59-4f7b-8ceb-0673761bcded"
      },
      "source": [
        "# Instantiate a neural net model\n",
        "activation_func = torch.tanh\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Apply initialization\n",
        "initialization='zero'\n",
        "model = apply_initialization(model, initialization)\n",
        "\n",
        "# Define optimizer: Choose SGD for now\n",
        "learning_rate = 0.01\n",
        "optimizer = torch.optim.SGD(model.parameters(), lr=learning_rate, momentum=0.9)\n",
        "\n",
        "# Run the training loop \n",
        "train_accs, test_accs, train_losses, test_losses = train_model(model, optimizer, train_dl, test_dl, epochs=10, print_every=2, debug=False)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "stream",
          "text": [
            "Using cuda\n",
            "Epoch 0, Train acc: 11.22%, Test acc: 11.35%\n",
            "Epoch 2, Train acc: 11.24%, Test acc: 11.35%\n",
            "Epoch 4, Train acc: 11.24%, Test acc: 11.35%\n",
            "Epoch 6, Train acc: 11.24%, Test acc: 11.35%\n",
            "Epoch 8, Train acc: 11.24%, Test acc: 11.35%\n"
          ],
          "name": "stdout"
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "bRNWeKOPQncY",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 573
        },
        "outputId": "52130549-4b5f-4b36-c1b5-5dafee1fd805"
      },
      "source": [
        "caption=\"Zero Initialization\"\n",
        "plot_acc_loss(train_accs, test_accs, train_losses, test_losses, caption)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAZUAAAEWCAYAAACufwpNAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nScXMzArjpGJmZoVxUjEzs8L8fyx3vdcmXP3KAAAAAElFTkSuQmCC\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAZUAAAEWCAYAAACufwpNAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nFTMzy42DipmZ5eb/A4rB7fKvXMVlAAAAAElFTkSuQmCC\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "tepIDa3mQSpE"
      },
      "source": [
        "That's pretty bad "
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "qFoRj9emRFUn",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 1000
        },
        "outputId": "f586e93c-85f4-4135-8fdd-bf025ec6ed28"
      },
      "source": [
        "# Instantiate a neural net model\n",
        "activation_func = torch.tanh\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Apply initialization\n",
        "initialization='zero'\n",
        "model = apply_initialization(model, initialization)\n",
        "\n",
        "# Define optimizer: Choose SGD for now\n",
        "learning_rate = 0.01\n",
        "optimizer = torch.optim.SGD(model.parameters(), lr=learning_rate, momentum=0.9)\n",
        "\n",
        "# Run the training loop \n",
        "train_accs, test_accs, train_losses, test_losses = train_model(model, optimizer, train_dl, test_dl, epochs=2, print_every=2, debug=True)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJcAAAE/CAYAAAD7fiLMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nSUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "stream",
          "text": [
            "Using cuda\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJcAAAE/CAYAAAD7fiLMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3kAAAE/CAYAAAD7bgqNAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
            "text/plain": [
              "<Figure size 1080x360 with 3 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "stream",
          "text": [
            "Epoch 0, Train acc: 11.22%, Test acc: 11.35%\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJcAAAE/CAYAAAD7fiLMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nAfzyCz9BZKhLAAAAAElFTkSuQmCC\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3kAAAE/CAYAAAD7bgqNAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
            "text/plain": [
              "<Figure size 1080x360 with 3 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "fZKEtoM0Vbqc"
      },
      "source": [
        "Observation: the activations and the gradients are all zero!"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "wvKDnI5pVn3S",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 119
        },
        "outputId": "71949f93-7bcd-4d1a-f114-f62c6a230dad"
      },
      "source": [
        "# Instantiate a neural net model\n",
        "activation_func = torch.tanh\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Apply initialization\n",
        "initialization='uniform'\n",
        "model = apply_initialization(model, initialization)\n",
        "\n",
        "# Define optimizer: Choose SGD for now\n",
        "learning_rate = 0.01\n",
        "optimizer = torch.optim.SGD(model.parameters(), lr=learning_rate, momentum=0.9)\n",
        "\n",
        "# Run the training loop \n",
        "train_accs, test_accs, train_losses, test_losses = train_model(model, optimizer, train_dl, test_dl, epochs=10, print_every=2, debug=False)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "stream",
          "text": [
            "Using cuda\n",
            "Epoch 0, Train acc: 15.82%, Test acc: 16.62%\n",
            "Epoch 2, Train acc: 15.75%, Test acc: 16.60%\n",
            "Epoch 4, Train acc: 15.80%, Test acc: 16.73%\n",
            "Epoch 6, Train acc: 15.60%, Test acc: 16.54%\n",
            "Epoch 8, Train acc: 15.74%, Test acc: 17.71%\n"
          ],
          "name": "stdout"
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "uPSzXzmuJv0Z",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 573
        },
        "outputId": "333c0e4c-01e0-44de-b9b3-fabc2f3c31b6"
      },
      "source": [
        "caption=\"Uniform Initialization\"\n",
        "plot_acc_loss(train_accs, test_accs, train_losses, test_losses, caption)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAY4AAAEWCAYAAABxMXBSAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nJiyWOIwxxoTFEocxxpiw/H9lNFU44puuyAAAAABJRU5ErkJggg==\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYgAAAEWCAYAAAB8LwAVAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nJQhjjDFh/X/sVitGmA+GoAAAAABJRU5ErkJggg==\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "gwhjoQfQVYgP",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 1000
        },
        "outputId": "59dce7c9-ed41-4224-c0cd-049929db00f3"
      },
      "source": [
        "# Instantiate a neural net model\n",
        "activation_func = torch.tanh\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Apply initialization\n",
        "initialization='uniform'\n",
        "model = apply_initialization(model, initialization)\n",
        "\n",
        "# Define optimizer: Choose SGD for now\n",
        "learning_rate = 0.01\n",
        "optimizer = torch.optim.SGD(model.parameters(), lr=learning_rate, momentum=0.9)\n",
        "\n",
        "# Run the training loop \n",
        "train_accs, test_accs, train_losses, test_losses = train_model(model, optimizer, train_dl, test_dl, epochs=2, print_every=2, debug=True)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJAAAAE/CAYAAAAZojm1AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "stream",
          "text": [
            "Using cuda\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJcAAAE/CAYAAAD7fiLMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAADh0RVh0U29mdHdhcmUAbWF0cGxvdGxpYiB2ZXJzaW9uMy4xLjIsIGh0\ndHA6Ly9tYXRwbG90bGliLm9yZy8li6FKAAAgAElEQVR4nO3de5hkdX3v+/dHRvCK3CYEGXBImFzQ\no4izEWMSiRgFNMI+QQIxMnqIkwRMzI77GMxl4/bybN07WyNPlIQIYVAicogGtg4SghBjIsh4CYho\nGBHCIJeRq4qoo9/zx/o1FE33dM+a7urqrvfreeqptX7rt9b6VlXXt6u+tdZvpaqQJEmSJEmS+njM\nQgcgSZIkSZKkxcvikiRJkiRJknqzuCRJkiRJkqTeLC5JkiRJkiSpN4tLkiRJkiRJ6s3ikiRJkiRJ\nknqzuDRCktyU5EU91vudJHck+XaS3ecjtr6S/GWSP51l37OTvG0eY/lQkqPna/ujJsmvJPnwHG7v\n4iRr5mp7Gl3mInPRXEryzCT/Oofbm/VrqcXNXGQumkvmIm0P85H5aC4t1e9pFpdmKclxSa5K8p0k\nd7bpk5JkgeN6LPAu4MVV9aSqums7t/emJBdParthmrbjZtpeVf12Vb11e2Ia2Gcl2b/nus8EngVc\n2OZfneTTcxHXXEqyW5KPtr+zm5P8+gz935rk2iRbkrx5cFlV/R/g6e2xT7f+rP9RVtURVbWurTeS\nz984MBeZi4YhyeuSbEjyvSRnz9B3pyRntpz1rSRfTHLExPKquga4N8mvbGUbVyT5zdnENvhaJjk0\nyabZPSrNJXORuWi+zZRbplnng0luS3J/kn8fzCvmoqXLfGQ+Goat5ZcZ1luV5MEkH5xoW6rf0ywu\nzUKSNwDvAf4X8OPAnsBvA88HdpxmnR2GFN6ewOOA67Z1xXQm/w18Cvi5ifiT7AU8Fnj2pLb9W9/F\n4reAc6uqFjoQmPa5B3gv8H261/WVwOlJnr6VTW0E3gh8fJrlHwLWbk+sGh3mInPRXNtKLvoG8Dbg\nrFlsZhlwC/AC4CnAnwDnJ1k50OdcuseuJcBcZC6aa9M897PJLZP9D2BlVe0MvBx4W5LnDCw3Fy0x\n5iPz0VzbymejmfLLdN4LXD1F+5L7nmZxaQZJngK8BTipqi6oqm9V5wtV9cqq+l7rd3aS05OsT/Id\n4JeSvDTJF1p185ZMOrIkyavS/RpzV5I/nrTs4HS/Gt+f7lDKd00R208BX22z9yb5ZGv/uSRXJ7mv\n3f/cwDpXJHl7kn8BHgB+YtJmr6ZLUge2+V8ALm/7GWz7WlV9o23zZ5JcmuTuJF9NcuzA/h5xCGWS\nN7aK7zeS/GYeXeXeNcnH0/1CdVWSn2zrTSTIf0t3WOmvJdkjyceS3Nv2/c/TJAKAI4B/mmbZIyR5\nTZLrWww3JvmtgWVfysAvXkkem+SbSZ7d5g9J8q8tpn9LcuhA360+90meCPwq8KdV9e2q+jRwEfCq\n6WKtqnVVdTHwrWm6XAG8dJaP+9VJPp3kz5Lck+TrGfiFsMX/m0l+FvhL4Hnttbh3NtvX9jEXmYuG\nlYsAquojVfX3wIy/slbVd6rqzVV1U1X9qKo+BnwdGPzAdQVwWJKdZvG4D02yKckb0v0CfVuS1wws\nPzvJ21rOvBh4anstvp3kqTNtX9vHXGQuGlYummVuYdI61038DQLVbj850OUKzEVLhvnIfDSsfASz\nyi9TxXsccC9w2RSLr2CpfU+rKm9buQGHA1uAZTP0Oxu4j65K/hi6KvWhwP/V5p8J3AEc3fofAHwb\n+EVgJ7pDJrcAL2rLPwO8qk0/CThkmv2upPvDXtbmdwPuoStILAOOb/O7t+VXAP8BPL0tf+wU27wc\n+C9t+i+A/wd4+6S2s9r0E+l+VXpN296zgW8CBww8L28beC5vb/t+AvDBFvv+A33vAg5u2zoXOG8g\nrof6tvn/QffmeWy7/QKQKR7PE9u6ywfaXg18eprn9KV0iSJ0v5Y9ABzUlr0R+PBA36OAa9v03i3+\nI9tr/sttfvlsnvv23D0wqe2/Av9nFn+nHwTePEX7bu2x7zzNejcN/M29GvgB8FpgB+B36I5eyED8\nvznT8+dtfm6Yi8xFQ8pFk2J4G3D2Nv6t7gk8CPzMpPb7gWdOs84VPJxfDqX7G3xLez6PbI991yle\ny0OBTQv9/hynG+Yic9EC5KLWf8rcMkW/97UYC/g88KRJy81FS+SG+ch8NOR8xAz5ZVLfnYF/B1YA\nbwY+OGn5kvue5pFLM9sD+GZVbZloGKh4fjfJLw70vbCq/qW6X1cerKorquraNn8N3aFvL2h9jwE+\nVlWfqq4C+qfAjwa29QNg/yR7VHcUy5WzjPelwA1V9YGq2lJVHwK+AgyeX352dZXXLVX1gym28U90\nyRS6RPDP7TbYNlFdfhlwU1X9TdveF4C/A14xxXaPBf6m7fsBujfZZB+tqs+25/tcHq7CT+UHwF7A\n06rqB1X1z9XeUZPs0u6nO7rnEarq41X1ter8E/APdI8ZukR7ZJKd2/yrgA+06d8A1lfV+vaaXwps\noEtiE7b23D+J7gPPoPuAJ88m7mlMPOZdttrrYTdX1V9X1Q+BdXTP757bsX/NHXORuWhYuai3dONL\nnAusq6qvTFr8LWafi34AvKU9n+vpPuT/9FzFqe1iLjIXDT0XzZBbJsd7Et1np18APgJ8b1IXc9HS\nYT4yHw01H80ivwx6K3BmVU03HtuS+55mcWlmdwF7JFk20VBVP1dVu7Rlg8/hLYMrJnluksuTbE5y\nH935v3u0xU8d7F9V3+GRpx+cCPwU8JV2yOTLZhnvU4GbJ7XdTFetnTLOKXwK+Pkku9FVc28A/pXu\nHN/dgGfw8Hm8TwOe25L4ve3Qu1fSnfM8VWyD+54qjtsHph+gK7hM53/RjTn0D+2wyFOm6TdxOOCs\nijRJjkhyZTuE8166pLMHQHWHmP4L8KtJdqE7jPPcturTgFdMei5+nu6NP2Frz/236Srcg3amJZ4k\n1+Xhw61/4VFrT23iMc/2kMiHnv/2jwW2/hpoeMxF5qJh5aKZ4rp4IBe9cqD9MXQf4r4PvG6KVZ/M\n7HPRXYNfFpj5NdDwmIvMRUPNRdPllulyUYvrh9UNL7CC7hf+QeaipcN8ZD4a+mejqfLL5HyU5EDg\nRcC7t7KpJfc9bdnMXcbeZ+gqkkfRVXq3ZnI19m/pDk08oqoeTPLnPJy0bgN+dqJjkicAD12esiWK\n49s/1P8buCDJ7i25bc036N48g/YFPrGVOCf7DN3Aia+le4NSVfcn+UZr+0ZVfb31vQX4p6r65Rm2\nCd1jXjEwv88s1plWVX0LeAPwhiTPAD6Z5OqqumxSv+8k+RrdP4HNW9tmunPw/w44ge4Xjh8k+Xu6\nQy8nrAN+k+7985mqurW13wJ8oKpeu7Wwt7Ls34FlSVa11x+6Kydc1x7H1gb2ns7P0v1iMfmIqO01\n09+Q5p65CHMRw8lFW1VVj7paU5IAZ9L9gnbk5F/8kuxNN7DqVyevu53MRcNnLsJcxJBy0dZyy1S5\naArLGBgTxVy05JiPMB+xcJ+NHsovk/NRkt+nOy3yP7o0xpOAHZIcUFUHtW5L7nuaRy7NoKruBf47\n8L4kxyR5cpLHtGrkE2dY/cnA3S1hHQwMXlb+AuBlSX4+yY5053M/9Hok+Y0ky6vqRzxczRw8HHM6\n64GfSvLrSZYl+TW684Y/NpvHC1BV36U7TPAP6A6znPDp1jZ49YGPtf29Kt2gaY9N8p/SDSY22fnA\na5L8bEvSfzrbmJo7GBhcLcnLkuzfPnjcB/yQ6Z+j9Tx8qOvAJvK4wRvdB46d6JLblnQDpb140np/\nDxwEvB44Z6D9g8CvJHlJkh3aNg9NsoJZaP+QPgK8JckTkzyf7p/lB6Zbpz3fj6P721nW9jl4BYwX\n0A0yOdfuAFa0v10NgbnIXMSQclELaFmLYwe6D0OPy8Avw1M4ne5D0q+0122yFwCfrIcHwpwrdwC7\npxvUVUNgLjIXMcRcxMy5ZTD4H0t3Sfontf29hG5Mm8Evs+aiJcR8ZD5iSPlolvll0Bl0hacD2+0v\n6a7u/ZKBPkvue5rFpVmoqv9J92Z9I92LdQfwV8Af0h2GOJ2T6AoF3wL+G92bdmKb1wEn01XNb6Mb\nzG3wfMzDgeuSfJvu8prHzfRPtW33Lrrza99Ad/jmG4GXVdU3Z/VgH/ZPwI/RJaoJ/9zaHkparSr9\nYuA4umr87cA76d74k2O7GDiNbiC6jcDE+cmz/Qf/ZmBdukMZjwVWAf9IdzrZZ4D3VdXl06x7BvDK\nluAm/Bzw3Sluv0f3Wt1D94/mokmP47t0VfP96IpBE+230BWD/ogu6d0C/L9s2/vsJODxwJ10537/\nTvtbmc5ft5iPB/64TQ9eXe54ur/VufZJuiOqbk+yrX9b6slc9BBzEfOei/6kxXAK3TgF321tj5Lk\naXSXET6QLidMdZrKK+k+WM2p6sZe+RBwY3s9vELTEJiLHmIuYv5y0SxzyyNCoTtFZVOL9c+A36+q\nwXjNRUuM+egh5iPm9bPRbPLLYBwPVNXtEze65+HBqho8OmvJfU+bGF1cGrpWNf8SsFM98nz2+drf\n3wLnV3d57e3d1n8DfqqqfmP7I5sf6S7F+aqqOnbGztIYMxfNryTPBP6qqp630LFIo8xcNL/MRdLs\nmY/m11L9nmZxSUOV5D/THfr4BLpzYn9UVUcvbFTbJt1geV+gSwifmqm/pNFjLpI0CsxFkkaF+Ujb\ny9PiNGy/RXfK19fozr2dfAWPkZbktXSHUV5swpIWNXORpFFgLpI0KsxH2i4euSRJkiRJkqTePHJJ\nkiRJkiRJvVlckiRJkiRJUm/LFjqAubbHHnvUypUrFzoMSdvpc5/73DeravlCx9GXuUhaGsxFkkaB\nuUjSKNhaLlpyxaWVK1eyYcOGhQ5D0nZKcvNCx7A9zEXS0mAukjQKzEWSRsHWcpGnxUmSJEmSJKk3\ni0uSJEmSJEnqzeKSJEmSJEmSerO4JEmSJEmSpN4sLkmSJEmSJKk3i0uSJEmSJEnqzeKSJEmSJEmS\nerO4JEmSJEljLMkuSS5I8pUk1yd5XpLdklya5IZ2v2vrmySnJdmY5JokBy10/JIWnsUlSZIkSRpv\n7wE+UVU/AzwLuB44BbisqlYBl7V5gCOAVe22Fjh9+OFKGjUWlyRJkiRpTCV5CvCLwJkAVfX9qroX\nOApY17qtA45u00cB51TnSmCXJHsNOWxJI8bikiRJkiSNr/2AzcDfJPlCkvcneSKwZ1Xd1vrcDuzZ\npvcGbhlYf1NrkzTGli10ANK2WnnKx+dluze946Xzsl1JS5O5SNKoMB9pOy0DDgJ+t6quSvIeHj4F\nDoCqqiS1LRtNspbutDn23XffuYpVc2C+csZiY46bWx65JEmSJEnjaxOwqaquavMX0BWb7pg43a3d\n39mW3wrsM7D+itb2CFV1RlWtrqrVy5cvn7fgJY0Gi0uSJEmSNKaq6nbgliQ/3ZoOA74MXASsaW1r\ngAvb9EXACe2qcYcA9w2cPidpTHlanCRJkiSNt98Fzk2yI3Aj8Bq6AxHOT3IicDNwbOu7HjgS2Ag8\n0PpKGnMWlyRJkiRpjFXVF4HVUyw6bIq+BZw870FJWlQ8LU6SJEmSJEm9WVySJEmSJElSbxaXJEmS\nJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvFJUmSJEmSJPVmcUmS\nJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVySJEmSJElSbxaX\nJEmSJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvFJUmSJEmSJPVm\ncUnSopfkvyS5LsmXknwoyeOS7JfkqiQbk3w4yY6t705tfmNbvnJgO29q7V9N8pKB9sNb28Ykpwz/\nEUpaLMxHkiRpHFlckrSoJdkb+D1gdVU9A9gBOA54J/DuqtofuAc4sa1yInBPa39360eSA9p6TwcO\nB96XZIckOwDvBY4ADgCOb30l6RHMR5IkaVxZXJK0FCwDHp9kGfAE4DbghcAFbfk64Og2fVSbpy0/\nLEla+3lV9b2q+jqwETi43TZW1Y1V9X3gvNZXkqZiPpIkSWPH4pKkRa2qbgX+DPgPui9x9wGfA+6t\nqi2t2yZg7za9N3BLW3dL67/7YPukdaZrl6RHMB9JkqRxZXFJ0qKWZFe6X+73A54KPJHuNJKFiGVt\nkg1JNmzevHkhQpC0gEYlH5mLJEnSsFlckrTYvQj4elVtrqofAB8Bng/s0k5LAVgB3NqmbwX2AWjL\nnwLcNdg+aZ3p2h+lqs6oqtVVtXr58uVz8dgkLS4jkY/MRZIkadgsLkla7P4DOCTJE9pYJYcBXwYu\nB45pfdYAF7bpi9o8bfknq6pa+3Ht6k37AauAzwJXA6va1Z52pBtk96IhPC5Ji4/5SJIkjaVlM3eR\npNFVVVcluQD4PLAF+AJwBvBx4Lwkb2ttZ7ZVzgQ+kGQjcDfdlzOq6rok59N9EdwCnFxVPwRI8jrg\nErorP51VVdcN6/FJWjzMR5IkaVxZXJK06FXVqcCpk5pvpLuy0uS+DwKvmGY7bwfePkX7emD99kcq\naakzH0mSpHHkaXGSJEmSJEnqbcbiUpJ9klye5MtJrkvy+ta+W5JLk9zQ7ndt7UlyWpKNSa5JctDA\ntta0/jckWTPQ/pwk17Z1TmvjFEy7D0mSJEmSJI2G2Ry5tAV4Q1UdABwCnJzkAOAU4LKqWgVc1uYB\njqAbeHIVsBY4HbpCEd1h4s+lOzT81IFi0enAawfWm7hs73T7kCRJkiRJ0giYsbhUVbdV1efb9LeA\n64G9gaOAda3bOuDoNn0UcE51rqS7/O5ewEuAS6vq7qq6B7gUOLwt27mqrmxXSDln0ram2ockSZIk\nSZJGwDaNuZRkJfBs4Cpgz6q6rS26HdizTe8N3DKw2qbWtrX2TVO0s5V9SJIkSZIkaQTMuriU5EnA\n3wG/X1X3Dy5rRxzVHMf2CFvbR5K1STYk2bB58+b5DEOSJEmSlpQkN7UxcL+YZENr2+YxdiWNr1kV\nl5I8lq6wdG5VfaQ139FOaaPd39nabwX2GVh9RWvbWvuKKdq3to9HqKozqmp1Va1evnz5bB6SJEmS\nJOlhv1RVB1bV6ja/TWPsShpvs7laXIAzgeur6l0Diy4CJq74tga4cKD9hFbRPgS4r53adgnw4iS7\ntqr3i4FL2rL7kxzS9nXCpG1NtQ9JkiRJ0vzZ1jF2JY2xZbPo83zgVcC1Sb7Y2v4IeAdwfpITgZuB\nY9uy9cCRwEbgAeA1AFV1d5K3Ale3fm+pqrvb9EnA2cDjgYvbja3sQ5IkSZI0Nwr4hyQF/FVVncG2\nj7F7G5LG1ozFpar6NJBpFh82Rf8CTp5mW2cBZ03RvgF4xhTtd021D0mSJEnSnPn5qro1yY8Blyb5\nyuDCqqpWeJq1JGvpTptj3333nbtIJY2kbbpanCRJkiRpaamqW9v9ncBHgYPZ9jF2J2/TcXGlMWJx\nSZIkSZLGVJInJnnyxDTd2LhfYtvH2JU0xmYz5pIkSZIkaWnaE/hod20llgF/W1WfSHI12zDGrqTx\nZnFJkiRJksZUVd0IPGuK9inHv93aGLuSxpenxUmSJEmSJKk3i0uSJEmSJEnqzeKSJEmSJEmSerO4\nJEmSJEmSpN4sLkmSJEmSJKk3i0uSJEmSJEnqzeKSJEmSJEmSerO4JEmSJEmSpN4sLkmSJEmSJKk3\ni0uSJEmSJEnqzeKSJEmSJEmSerO4JEmSJEmSpN4sLkmSJEmSJKk3i0uSJEmSJEnqzeKSJEmSJEmS\nerO4JEmSJEmSpN4sLkmSJEmSJKk3i0uSJEmSJEnqzeKSJEmSJEmSerO4JEmSJEmSpN4sLkmSJEmS\nJKk3i0uSJEmSJEnqzeKSJEmSJEmSerO4JEmSJEmSpN4sLkmSJEmSJKk3i0uSJEmSJEnqzeKSJEmS\nJEmSerO4JEmSJEmSpN4sLkmSJEmSJKk3i0uSJEmSJEnqzeKSJEmSJEmSerO4JEmSJEmSpN4sLkmS\nJEmSJKk3i0uSJEmSJEnqzeKSpEUvyS5JLkjylSTXJ3lekt2SXJrkhna/a+ubJKcl2ZjkmiQHDWxn\nTet/Q5I1A+3PSXJtW+e0JFmIxylp9JmPJC1WSXZI8oUkH2vz+yW5quWbDyfZsbXv1OY3tuUrFzJu\nSaPB4pKkpeA9wCeq6meAZwHXA6cAl1XVKuCyNg9wBLCq3dYCpwMk2Q04FXgucDBw6sQXwNbntQPr\nHT6ExyRpcTIfSVqsXk+Xsya8E3h3Ve0P3AOc2NpPBO5p7e9u/SSNOYtLkha1JE8BfhE4E6Cqvl9V\n9wJHAetat3XA0W36KOCc6lwJ7JJkL+AlwKVVdXdV3QNcChzelu1cVVdWVQHnDGxLkh5iPpK0WCVZ\nAbwUeH+bD/BC4ILWZXLumshpFwCHeRSlJItLkha7/YDNwN+0Q7nfn+SJwJ5VdVvrczuwZ5veG7hl\nYP1NrW1r7ZumaJekycxHkharPwfeCPyoze8O3FtVW9r8YL55KEe15fe1/pLGmMUlSYvdMuAg4PSq\nejbwHR4+5QSA9gt/zXcgSdYm2ZBkw+bNm+d7d5JGz0jkI3ORpG2R5GXAnVX1uTnerrlIGiMWlyQt\ndpuATVV1VZu/gO7L3R3tFBLa/Z1t+a3APgPrr2htW2tfMUX7o1TVGVW1uqpWL1++fLselKRFaSTy\nkblI0jZ6PvDyJDcB59GdDvceulN1l7U+g/nmoRzVlj8FuGvyRs1F0nixuCRpUauq24Fbkvx0azoM\n+DJwETBxhaU1wIVt+iLghHaVpkOA+9rpKpcAL06yaxs498XAJW3Z/UkOaeMJnDCwLUl6iPlI0mJU\nVW+qqhVVtRI4DvhkVb0SuBw4pnWbnLsmctoxrf+8HyEuabQtm7mLJI283wXObZfIvRF4DV3x/Pwk\nJwI3A8e2vuuBI4GNwAOtL1V1d5K3Ale3fm+pqrvb9EnA2cDjgYvbTZKmYj6StFT8IXBekrcBX6Bd\nrKDdfyDJRuBuuoKUpDE3Y3EpyVnAxHm4z2htb6a7DO7EybN/VFXr27I30V2e8ofA71XVJa39cLrD\nK3cA3l9V72jt+9Edfrk78DngVVX1/SQ70V0F5Tl0h1n+WlXdNAePWdISU1VfBFZPseiwKfoWcPI0\n2zkLOGuK9g3AM7YzTEljwHwkaTGrqiuAK9r0jcDBU/R5EHjFUAOTNPJmc1rc2cDhU7S/u6oObLeJ\nwtIBdJXrp7d13pdkhyQ7AO8FjgAOAI5vfQHe2ba1P3APXWGKdn9Pa3936ydJkiRJkqQRMmNxqao+\nRXe442wcBZxXVd+rqq/THeZ9cLttrKobq+r7dEcqHdXGC3gh3YCXAOuAowe2ta5NXwAc1vpLkiRJ\nkiRpRGzPgN6vS3JNkrPaYJMAewO3DPTZ1Nqma98duLeqtkxqf8S22vL7Wn9JkiRJkiSNiL7FpdOB\nnwQOBG4D/vecRdRDkrVJNiTZsHnz5plXkCRJkiRJ0pzoVVyqqjuq6odV9SPgr3l4oLdbgX0Guq5o\nbdO13wXskmTZpPZHbKstf0rrP1U8Z1TV6qpavXz58j4PSZIkSZIkST30Ki4l2Wtg9j8DX2rTFwHH\nJdmpXQVuFfBZukvprkqyX7s073HARe0qKZcDx7T11wAXDmxrTZs+Bvhk6y9JkiRJkqQRsWymDkk+\nBBwK7JFkE3AqcGiSA4ECbgJ+C6CqrktyPvBlYAtwclX9sG3ndcAlwA7AWVV1XdvFHwLnJXkb8AXg\nzNZ+JvCBJBvpBhQ/brsfrSRJkiRJkubUjMWlqjp+iuYzp2ib6P924O1TtK8H1k/RfiMPn1Y32P4g\n8IqZ4pMkSZIkSdLC2Z6rxUmSJEmSJGnMWVySJEmSJElSbxaXJEmSJEmS1JvFJUmSJEmSJPVmcUmS\nJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVySJEmSJElSbxaX\nJEmSJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvFJUmSJEmSJPVm\ncUmSJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVySJEmSJElS\nbxaXJEmSJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvFJUmSJEka\nU0kel+SzSf4tyXVJ/ntr3y/JVUk2Jvlwkh1b+05tfmNbvnIh45c0GiwuSZIkSdL4+h7wwqp6FnAg\ncHiSQ4B3Au+uqv2Be4ATW/8TgXta+7tbP0ljzuKSJEmSJI2p6ny7zT623Qp4IXBBa18HHN2mj2rz\ntOWHJcmQwpU0opYtdACSJEmSpIWTZAfgc8D+wHuBrwH3VtWW1mUTsHeb3hu4BaCqtiS5D9gd+Oak\nba4F1gLsu+++s45l5Skf7/04lpqb3vHShQ5BI2S+3htz9XfmkUuSJEmSNMaq6odVdSCwAjgY+Jk5\n2OYZVbW6qlYvX758u2OUNNosLkmSJEmSqKp7gcuB5wG7JJk402UFcGubvhXYB6Atfwpw15BDlTRi\nLC5JkiRJ0phKsjzJLm368cAvA9fTFZmOad3WABe26YvaPG35J6uqhhexpFHkmEuSJEmSNL72Ata1\ncZceA5xfVR9L8mXgvCRvA74AnNn6nwl8IMlG4G7guIUIWtJosbgkSZIkSWOqqq4Bnj1F+4104y9N\nbn8QeMUQQpO0iHhanCRJkiRJknqzuCRJkiRJkqTeLC5JkiRJkiSpN4tLkiRJkiRJ6s3ikiRJkiRJ\nknqzuCRpSUiyQ5IvJPlYm98vyVVJNib5cJIdW/tObX5jW75yYBtvau1fTfKSgfbDW9vGJKcM+7FJ\nWjzMRZIkaRxZXJK0VLweuH5g/p3Au6tqf+Ae4MTWfiJwT2t/d+tHkgOA44CnA4cD72tfEncA3gsc\nARwAHN/6StJUzEWSJGnsWC+a84cAABLeSURBVFyStOglWQG8FHh/mw/wQuCC1mUdcHSbPqrN05Yf\n1vofBZxXVd+rqq8DG4GD221jVd1YVd8Hzmt9JekRzEWSJGlcWVyStBT8OfBG4Edtfnfg3qra0uY3\nAXu36b2BWwDa8vta/4faJ60zXbskTWYukiRJY8nikqRFLcnLgDur6nMjEMvaJBuSbNi8efNChyNp\niMxFkiRpnM1YXEpyVpI7k3xpoG23JJcmuaHd79rak+S0NtDkNUkOGlhnTet/Q5I1A+3PSXJtW+e0\ndkj4tPuQpEmeD7w8yU10p4m8EHgPsEuSZa3PCuDWNn0rsA9AW/4U4K7B9knrTNf+KFV1RlWtrqrV\ny5cv3/5HJmkxMRdJkqSxNZsjl86mG1By0CnAZVW1CriszUM3yOSqdlsLnA5doQg4FXgu3ZgBpw4U\ni04HXjuw3uEz7EOSHlJVb6qqFVW1km4Q3E9W1SuBy4FjWrc1wIVt+qI2T1v+yaqq1n5cu4LTfnT5\n6LPA1cCqdsWnHds+LhrCQ5O0iJiLJEnSOJuxuFRVnwLuntQ8OAjl5MEpz6nOlXS/1u0FvAS4tKru\nrqp7gEuBw9uynavqyvaB6hymHuhycB+SNBt/CPxBko1045ic2drPBHZv7X9AK1xX1XXA+cCXgU8A\nJ1fVD9tYKK8DLqG7AtT5ra8kzYa5SJIkLXnLZu4ypT2r6rY2fTuwZ5ve1kEo927Tk9u3tg9JmlJV\nXQFc0aZvpDtScnKfB4FXTLP+24G3T9G+Hlg/h6FKWsLMRZIkadxs94De7YijmoNYeu/DgSslSZIk\nSZIWRt/i0h3tlDba/Z2tfVsHoby1TU9u39o+HsWBKyVJkiRJkhZG3+LS4CCUkwenPKFdNe4Q4L52\natslwIuT7NoG8n4xcElbdn+SQ9pV4k5g6oEuB/chSZIkSZKkETHjmEtJPgQcCuyRZBPdVd/eAZyf\n5ETgZuDY1n09cCSwEXgAeA1AVd2d5K10VzoBeEtVTQwSfhLdFekeD1zcbmxlH5IkSZIkSRoRMxaX\nqur4aRYdNkXfAk6eZjtnAWdN0b4BeMYU7XdNtQ9JkiRJkiSNju0e0FuSJEmSJEnjy+KSJEmSJEmS\nerO4JEmSJEmSpN4sLkmSJEmSJKk3i0uSJEmSJEnqzeKSJEmSJEmSerO4JEmSJEmSpN4sLkmSJEmS\nJKk3i0uSJEmSJEnqzeKSJEmSJEmSerO4JEmSJEmSpN4sLkmSJEmSJKk3i0uSJEmSJEnqzeKSJEmS\nJEmSerO4JEmSJEmSpN4sLkmSJEnSmEqyT5LLk3w5yXVJXt/ad0tyaZIb2v2urT1JTkuyMck1SQ5a\n2EcgaRRYXJIkSZKk8bUFeENVHQAcApyc5ADgFOCyqloFXNbmAY4AVrXbWuD04YcsadRYXJIkSZKk\nMVVVt1XV59v0t4Drgb2Bo4B1rds64Og2fRRwTnWuBHZJsteQw5Y0YiwuSZIkSZJIshJ4NnAVsGdV\n3dYW3Q7s2ab3Bm4ZWG1Ta5M0xiwuSZIkSdKYS/Ik4O+A36+q+weXVVUBtY3bW5tkQ5INmzdvnsNI\nJY0ii0uSJEmSNMaSPJausHRuVX2kNd8xcbpbu7+ztd8K7DOw+orW9ghVdUZVra6q1cuXL5+/4CWN\nBItLkiRJkjSmkgQ4E7i+qt41sOgiYE2bXgNcONB+Qrtq3CHAfQOnz0kaU8sWOgBJkiRJ0oJ5PvAq\n4NokX2xtfwS8Azg/yYnAzcCxbdl64EhgI/AA8JrhhitpFFlckiRJkqQxVVWfBjLN4sOm6F/AyfMa\nlKRFx9PiJEmSJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvFJUmS\nJEmSJPVmcUmSJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVyS\nJEmSJElSbxaXJEmSJEmS1JvFJUmSJEmSJPVmcUmSJEmSJEm9WVySJEmSJElSbxaXJEmSJEmS1JvF\nJUmSJEmSJPVmcUmSJEmSJEm9WVyStKgl2SfJ5Um+nOS6JK9v7bsluTTJDe1+19aeJKcl2ZjkmiQH\nDWxrTet/Q5I1A+3PSXJtW+e0JBn+I5U06sxHkiRpXFlckrTYbQHeUFUHAIcAJyc5ADgFuKyqVgGX\ntXmAI4BV7bYWOB26L3/AqcBzgYOBUye+ALY+rx1Y7/AhPC5Ji4/5SJIkjSWLS5IWtaq6rao+36a/\nBVwP7A0cBaxr3dYBR7fpo4BzqnMlsEuSvYCXAJdW1d1VdQ9wKXB4W7ZzVV1ZVQWcM7AtSXqI+UiS\nJI2r7SouJbmpHZr9xSQbWpuHfktaEElWAs8GrgL2rKrb2qLbgT3b9N7ALQOrbWptW2vfNEW7JE3L\nfCRJksbJXBy59EtVdWBVrW7zHvotaeiSPAn4O+D3q+r+wWXtF/4aQgxrk2xIsmHz5s3zvTtJI2qh\n85G5SJIkDdt8nBbnod+ShirJY+m+yJ1bVR9pzXe0PEK7v7O13wrsM7D6ita2tfYVU7Q/SlWdUVWr\nq2r18uXLt+9BSVqURiEfmYskSdKwbW9xqYB/SPK5JGtbm4d+SxqadrrsmcD1VfWugUUXAROn2a4B\nLhxoP6GdqnsIcF/LWZcAL06yazt68sXAJW3Z/UkOafs6YWBbkvQQ85EkSRpXy7Zz/Z+vqluT/Bhw\naZKvDC6sqkoylFNR6E61Y999953v3UkaLc8HXgVcm+SLre2PgHcA5yc5EbgZOLYtWw8cCWwEHgBe\nA1BVdyd5K3B16/eWqrq7TZ8EnA08Hri43SRpMvORJEkaS9tVXKqqW9v9nUk+Sjdm0h1J9qqq27bh\n0O9DJ7VfwTaeigKcAbB69ep5L2ZJGh1V9WlgusH+D5uifwEnT7Ots4CzpmjfADxjO8KUNAbMR5Ik\naVz1Pi0uyROTPHlimu6Q7S/hod+SJEmSJEljY3uOXNoT+GhX92EZ8LdV9YkkV+Oh35IkSZIkSWOh\nd3Gpqm4EnjVF+1146LckSZIkSdJY2N6rxUmSJEmSJGmMWVySJEmSJElSbxaXJEmSJEmS1JvFJUmS\nJEkaY0nOSnJnki8NtO2W5NIkN7T7XVt7kpyWZGOSa5IctHCRSxoVFpckSZIkabydDRw+qe0U4LKq\nWgVc1uYBjgBWtdta4PQhxShphFlckiRJkqQxVlWfAu6e1HwUsK5NrwOOHmg/pzpXArsk2Ws4kUoa\nVRaXJEmSJEmT7VlVt7Xp24E92/TewC0D/Ta1NkljzOKSJEmSJGlaVVVAbcs6SdYm2ZBkw+bNm+cp\nMkmjwuKSJEmSJGmyOyZOd2v3d7b2W4F9BvqtaG2PUFVnVNXqqlq9fPnyeQ9W0sKyuCRJkiRJmuwi\nYE2bXgNcONB+Qrtq3CHAfQOnz0kaU8sWOgBJkiRJ0sJJ8iHgUGCPJJuAU4F3AOcnORG4GTi2dV8P\nHAlsBB4AXjP0gCWNHItLkiRJkjTGqur4aRYdNkXfAk6e34gkLTaeFidJkiRJkqTeLC5JkiRJkiSp\nN4tLkiRJkiRJ6s3ikiRJkiRJknqzuCRJkiRJkqTeLC5JkiRJkiSpN4tLkiRJkiRJ6s3ikiRJkiRJ\nknqzuCRJkiRJkqTeLC5JkiRJkiSpN4tLkiRJkiRJ6s3ikiRJkiRJknqzuCRJkiRJkqTeLC5JkiRJ\nkiSpN4tLkiRJkiRJ6s3ikiRJkiRJknqzuCRJkiRJkqTeLC5JkiRJkiSpN4tLkiRJkiRJ6s3ikiRJ\nkiRJknqzuCRJkiRJkqTeLC5JkiRJkiSpN4tLkiRJkiRJ6s3ikiRJkiRJknqzuCRJkiRJkqTeLC5J\nkiRJkiSpN4tLkiRJkiRJ6s3ikiRJkiRJknqzuCRJkiRJkqTeLC5JkiRJkiSpN4tLkiRJkiRJ6s3i\nkiRJkiRJknqzuCRJkiRJkqTeLC5JkiRJkiSpt5EvLiU5PMlXk2xMcspCxyNpPJmLJI0K85GkUWAu\nkjRopItLSXYA3gscARwAHJ/kgIWNStK4MRdJGhXmI0mjwFwkabKRLi4BBwMbq+rGqvo+cB5w1ALH\nJGn8mIskjQrzkaRRYC6S9AijXlzaG7hlYH5Ta5OkYTIXSRoV5iNJo8BcJOkRli10AHMhyVpgbZv9\ndpKvLmQ8wB7ANxc4hm1hvEDeOddbfIjPbz9PW+gAtpW5aLsZL+aiSUYhZnPR9huF13FbLLZ4wXw0\n30YhXnPR9hmF13BrpoxvHt+D22JRPnezMYTnd1E8d9v4PEybi0a9uHQrsM/A/IrW9ghVdQZwxrCC\nmkmSDVW1eqHjmC3jnV/GuySYi4bAeOfXYosXFmfMQzBjPjIXbZ/FFi8svpiNd0lYVLlo1F/DUY5v\nlGOD0Y5vlGODuY9v1E+LuxpYlWS/JDsCxwEXLXBMksaPuUjSqDAfSRoF5iJJjzDSRy5V1ZYkrwMu\nAXYAzqqq6xY4LEljxlwkaVSYjySNAnORpMlGurgEUFXrgfULHcc2GonDP7eB8c4v410CzEVDYbzz\na7HFC4sz5nm3CPPRYnsdF1u8sPhiNt4lYJHlolF/DUc5vlGODUY7vlGODeY4vlTVXG5PkiRJkiRJ\nY2TUx1ySJEmSJEnSCLO4NAeS7Jbk0iQ3tPtdt9J35ySbkvzFMGOcFMOM8SY5MMlnklyX5Jokv7YA\ncR6e5KtJNiY5ZYrlOyX5cFt+VZKVw45xUjwzxfsHSb7cns/LkizoJWVnineg368mqSQje6UDdcxF\n8xanuWgemYuWHnPRvMVpLppH5qKlZdTf17PNk0k+keTeJB8bQkwjm2NmEdsvJvl8ki1JjhlWXNsQ\n34Lmu1nE99tJrk3yxSSfTnJArx1VlbftvAH/EzilTZ8CvHMrfd8D/C3wF6McL/BTwKo2/VTgNmCX\nIca4A/A14CeAHYF/Aw6Y1Ock4C/b9HHAhxfwOZ1NvL8EPKFN/86ox9v6PRn4FHAlsHqh4vU269fV\nXDT3MZqLFjje1s9ctIhu5qJ5idFctMDxtn7mokVyG/X39WzzJHAY8CvAx+Y5npHNMbOMbSXwTOAc\n4Jgh/62NdL6bZXw7D0y/HPhEn3155NLcOApY16bXAUdP1SnJc4A9gX8YUlzTmTHeqvr3qrqhTX8D\nuBNYPrQI4WBgY1XdWFXfB86ji3vQ4OO4ADgsSYYY46AZ462qy6vqgTZ7JbBiyDEOms3zC/BW4J3A\ng8MMTr2Zi+aeuWh+mYuWJnPR3DMXzS9z0dIz6u/rWeXJqroM+NYQ4hnlHDObfHJTVV0D/GgI8fSJ\nbyHz3Wziu39g9olAr4G5LS7NjT2r6rY2fTvdB6VHSPIY4H8D/3WYgU1jxngHJTmYrsr5tfkObMDe\nwC0D85ta25R9qmoLcB+w+1Cie7TZxDvoRODieY1o62aMN8lBwD5V9fFhBqbtYi6ae+ai+WUuWprM\nRXPPXDS/zEVLz6i/r7cpviEY5Ryzrflk2EY9380qviQnJ/ka3VF1v9dnR8t6hTeGkvwj8ONTLPrj\nwZmqqiRTVfpOAtZX1aZhFHjnIN6J7ewFfABYU1ULUQlecpL8BrAaeMFCxzKd9qH/XcCrFzgUTWIu\nMhfNFXORtoe5yFw0V8xF6mvU39dzFZ+WjlHOd1X1XuC9SX4d+BNgzbZuw+LSLFXVi6ZbluSOJHtV\n1W0tOd05RbfnAb+Q5CTgScCOSb5dVdMOGLjA8ZJkZ+DjwB9X1ZXzEedW3ArsMzC/orVN1WdTkmXA\nU4C7hhPeo8wmXpK8iO4fyguq6ntDim0qM8X7ZOAZwBXtQ/+PAxcleXlVbRhalHoUc5G5aAbmIg2F\nuchcNANzkebdqL+v5yK+IRrlHDOrfLKARj3fbevzdx5wep8deVrc3LiIhyt7a4ALJ3eoqldW1b5V\ntZLuEPBz5usD1CzMGG+SHYGP0sV5wRBjm3A1sCrJfi2W4+jiHjT4OI4BPllVC1X1nzHeJM8G/gp4\neVUt9D+QrcZbVfdV1R5VtbL9zV5JF7cfoEabuWjumYvml7loaTIXzT1z0fwyFy09o/6+njG+IRvl\nHDOb2BbSqOe72cS3amD2pcANvfZUQxxJfane6M41vay9CP8I7NbaVwPvn6L/q1nYq6LMGC/wG8AP\ngC8O3A4ccpxHAv9Od+7zH7e2t9C9KQEeB/x/wEbgs8BPLPDfwUzx/iNwx8DzedEoxzup7xV4VZSR\nv5mL5i1Oc9ECxjupr7loEdzMRfMWp7loAeOd1NdcNOK3UX9fzzZPAv8MbAa+SzdWzkvmMaaRzTGz\niO0/tefnO3RHU1035L+3kc53s4jvPcB1LbbLgaf32U/axiRJkiRJkqRt5mlxkiRJkiRJ6s3ikiRJ\nkiRJknqzuCRJkiRJkqTeLC5JkiRJkiSpN4tLkiRJkiRJ6s3ikiRJkiRJknqzuCRJkiRJkqTeLC5J\nkiRJkiSpt/8fTlTgKilG+IUAAAAASUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3kAAAE/CAYAAAD7bgqNAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
            "text/plain": [
              "<Figure size 1080x360 with 3 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "stream",
          "text": [
            "Epoch 0, Train acc: 16.07%, Test acc: 16.87%\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJcAAAE/CAYAAAD7fiLMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAADh0RVh0U29mdHdhcmUAbWF0cGxvdGxpYiB2ZXJzaW9uMy4xLjIsIGh0\ndHA6Ly9tYXRwbG90bGliLm9yZy8li6FKAAAgAElEQVR4nO3debQtdXnn//dHrmAckOmGKIMXIyZB\nf4p6gyRqJGIzOAT654QxiDaRJGonHZNOMImt7bCi3R3tuJxCCwGUiDRxIHINISgxJgG5qAFRkSuC\nXES4Mjqi6NN/1PdA3c0+w60z7nver7X2OrW/9a2qZ9ep/Zx9nl31rVQVkiRJkiRJ0hD3We4AJEmS\nJEmSNLksLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uL\nIMk1SZ4+YLnfSXJjku8k2X0xYhsqyXuSvGaOfU9N8sZFjOUDSY5erPWvNEmeneSDyx3HqCSV5BHL\nHYemZy4yFy2kJI9J8q/LHceooce5lo65yFy0kMxFGspcZC5aSP6Pdm+rrriU5JgkFyf5bpKb2vTL\nk2SZ47ov8FbgsKp6YFXdPM/1vTrJx0farpqm7ZjZ1ldVv11Vb5hPTL1tDj7gkzwGeCzw0fb8JUk+\nvRBxLaQkuyX5cDvOrk3y67P0f0OSy5PcleR1/XlV9XfAo9prn275a5J8v/3Rm3q8Y2FezcJI8vtJ\nvpnkjiSnJNlpuWNaTuYic9FSSPLKJBuT3Jnk1Fn67pTk5Jazvp3k80mOnJpfVZcBtyV59gzruDDJ\nD0Zy0d8t3CuavyS/3l7jd5N8JMluyx3TcjIXmYsW22y5ZZpl3p/khvaZ4StJfnNqnrlo+2QuMhct\nhZlyyyzL7d9yyvun2vwf7d5WVXEpyR8Afwn8T+BngD2B3waeBOw4zTI7LFF4ewL3A67Y1gXTGf1d\nfgr45an4kzwEuC/wuJG2R7S+k+K3gDOqqpY7EJh23wO8E/gh3e/1RcC7kzxqhlVtAv4IOHea+R8A\nTpglnGe3P3pTj1fO0n/JJDkcOBE4FHgY8HDgvy9rUMvIXGQuWmgz5KJvAG8ETpnDatYA1wFPBR4M\n/BlwVpJ1vT5n0L32mbxyJBdN+w/gUmt5+K+AY+mO9e8B71rWoJaRuchctNCm2fdzyS2j/hxYV1U7\nA78GvDHJE3rzzUXbEXORuWihzfC5aLbcMp13ApeMafd/tJ5VU1xK8mDg9cDLq+rsqvp2dT5XVS+q\nqjtbv1OTvDvJhiTfBX41yTOTfK5V867LyJklSY5N983DzUn+dGTeQem+Nb4j3emUbx0T2yOBK9vT\n25J8orX/cpJLktzefv5yb5kLk7wpyb/Q/UF6+MhqL6FLVAe2508BPtm202/7alV9o63z55Ocn+SW\nJFcmeX5ve1udRpnkj9JVfb+R5Ddz70r3rknOTfcN1cVJfrYtN5Uk/z1d5fYFSfZI8rEkt7Vt//M0\nyQDgSOCfppm3lSQvTfKlFsPVSX6rN+8L6X3jleS+Sb6V5HHt+cFJ/rXF9O9JDun1nXHfJ3kA8Bzg\nNVX1nar6NHAO3QeIsarqtKr6OPDtabpcCDxzLq97VLpvDv4lyTvasfTlJIf25j80yTlt329K8rLe\nvB2S/EmSr7b9eGmSfXqrf3q6b1ZuS/LOZNpvl44DTq6qK6rqVuANwEuGvJ5JZy4yFy1VLgKoqg9V\n1UeAWb9prarvVtXrquqaqvpJVX0M+BrQ/9B1IXBoBnyrleSQJJtbTvlWum/zXtSb/+AkpyfZ0o7j\nP+vv/yQv6+3HLyZ5fG/1Bya5rB2jH0xyv2nCeBHwd1X1qar6DvAa4P9P8qBtfT2TzlxkLlqqXDTH\n3MLIMldMHYNAtcfP9rpciLlou2AuMhctVS6COeWWcfEeA9wGXDBm9oX4P9o9qmpVPIAjgLuANbP0\nOxW4na5Sfh+6SvUhwP/Xnj8GuBE4uvU/APgO8CvATnSnTd4FPL3N/zfg2Db9QODgaba7ju7gXtOe\n7wbcSleQWAO8sD3fvc2/EPg68Kg2/75j1vlJ4Pfb9DuA/wS8aaTtlDb9ALpvlV7a1vc44FvAAb39\n8sbevvxm2/b9gfe32B/R63szcFBb1xnAmb247u7bnv858B66RHtfuoSaMa/nAW3Ztb22lwCfnmaf\nPpMuWYTu27LvAY9v8/4I+GCv71HA5W16rxb/M9rv/D+052vnsu/bvvveSNsf0n2ImO04fT/wujHt\nu7XXvvM0y10zdcyNmfcSumPy99v+fQHdMb5bm/8pum/L7kf3R20L8LQ2778ClwM/1/bjY7nnGCzg\nY8AuwL5tuSOmieHfgRf0nu/Rlt99uXPDUj8wF5mLligXjcTwRuDUbTxW9wR+APz8SPsdwGOmWeZC\n4DenmXcI3TH5Vrpj9KnAd4Gfa/NPpzud/kF0x+FXgOPbvOcB1wO/2PbjI4CHtXnXAJ8BHkp3vH4J\n+O1pYvgo8Mcjbd8BnrDcuWGpH5iLzEXLkIta/7G5ZUy/d7UYC/gs8MCR+eai7eCBuchctMS5iFly\ny0jfnelywN7A64D3j8z3f7TeY9WcuUS3o75VVXdNNfSqnt9P8iu9vh+tqn+p7tuVH1TVhVV1eXt+\nGd3pb09tfZ8LfKy6bx7upPvm4Se9df0IeESSPao7i+WiOcb7TOCqqnpfVd1VVR8Avgz0T+k9tboq\n411V9aMx6/gnuoQKXTL45/bot01VmJ8FXFNVf93W9zngb+n+iI56PvDXbdvfo3ujjfpwVX2m7e8z\nuKcSP86PgIfQ/XH+UVX9c7Wje8Qu7ed0Z/dsparOraqvVuefgH+ge83QJdtnJNm5PT8WeF+b/g1g\nQ1VtaL/z84GNdIlsykz7/oF0H3j6bqf7kDLU1GveZYY+H2nH89TjZb15NwH/u+3fD9J9O/LMVuF+\nEt0HnB9U1eeB9wIvbsv9JvBnVXVl24//Xltfa/7mqrqtqr5O94dyut/zA+n2wZSp6VX3DR3mInPR\n0uWiwdKNMXEGcFpVfXlk9reZORe9fSQXjY4F8ZqqurPti3OB56e7FOAY4NXVfWt9DfAX3HPG528C\n/6OqLmn7cVNVXdvfZlV9o6puAf6OuecimH9+nlTmInPRkueiWXLLaLwvp3tvPgX4EHDnSBdz0fbB\nXGQuWtJcNIfc0vcGujN7Nk8z3//RelZTcelmYI8ka6YaquqXq2qXNq+/L67rL5jkiUk+me702Nvp\nrgHeo81+aL9/VX2XrS8/OB54JPDldtrks+YY70OBa0farqWr2I6Nc4xPAU9ON0Dg2qq6CvhXuut8\ndwMezT3X8j4MeGL/wKc7Zfdnpomtv+1xcXyzN/09ugN3Ov+Tbsyhf2inRp44Tb/b2s85HexJjkxy\nUTuV8Da6xLMHQHWnmf4L8Jwku9CdynlGW/RhwPNG9sWT6ZLrlJn2/Xfoqtx9O9OST5Ircs+Abk+5\n19LjTb3m22boc3RV7dJ7/J/evOtH/hhcS/d7fChwS1V9e2Te1HG2D/DVGbY519/z6D6Zmp7TH6Ht\njLnIXLRUuWi2uD7ey0X9S0LuQ/dB7ofAuHEBHsTMueh3R3JR/y42t7Zjc8pULtqD7lu7a0fmLXYu\ngl5+XmXMReaiJc1F0+WW6XJRi+vH1Q0vsDfwOyOrNBdtH8xF5qIl/1w0LreM5qIkBwJPB942w6r8\nH61nNRWX/o2uKnnUHPqOVmT/hm7MnH2q6sF0pwdOXbd4A90vF4Ak9wfuvkVlVV1VVS8Efhp4C3B2\nujF5ZvMNujdQ3750p+JOF+eof6MbOPFldG9SquqOtu6XAd+oqq+1vtcB/zRy4D+wqkb/kEP3mvfu\nPd9nTJ85q+6boT+oqofTDaz2qvSuN+31+y7dm+iRs60z3TX4fwv8L2DP9gdqA/f83gBOo6uAPw/4\nt6qa2rfXAe8b2RcPqKo398OZYfNfAdYk2b/X9ljaQIBV9ai6Z0C3f57ttTS/QPetxegZUXO1V7LV\ntbb70h0H3wB2y9bX+PePs+uY5TrkObqCbh9MeSxwY83zjhsTylyEuYilyUUzqqoje7nojBZvgJPp\nLlt5zui3fkn2ohtc9cp7rXBudh057qZy0bfoviF92Mi8Rc1FSR5Od7nEVxZg3ZPGXIS5iCXKRTPl\nlnG5aIw19HKAuWi7Yi7CXMTyfS66O7eMyUWH0F0W+fUk36Qb5uQ5ST7bW97/0XpWTXGpqm6jG/n8\nXUmem+RBSe7TKpKzJZIH0VUOf5DkIKB/W/mzgWcleXKSHekGpOsP+vcbSdZW1U+4p6LZPyVzOhuA\nR6a7TemaJC+gu3b4Y3N5vQBV9X26UwVfRXeq5ZRPt7b+HQg+1rZ3bLqB0+6b5BeT/MKYVZ8FvDTJ\nL7RE/ZoxfWZyI70B1pI8K8kj2hvrduDHTL+PNnDP6a69VeR+/QfdB46d6K4xvSvdLW8PG1nuI8Dj\ngd+ju75+yvuBZyc5PN1gafdLN/jj3sxBS7AfAl6f5AFJnkT3B/N90y3T9vf96I6dNW2b/btgPBX4\n+Pil5+Sngd9t23keXSLcUFXX0X1T8udtm4+h+yZn6jab7wXekO72m0nymCS7j93CzE4Hjk9yQPsW\n4s/orvtedcxF5iKWKBe1gNa0OHYAptaxZoZF3k2XH57dfm+jngp8ou4ZDHOI/55kx3Rnbj4L+L9V\n9WO63+eb2nviYXTHRj8X/WGSJ7Rc9IjWZ1udQbdPn9L+iXg98KGRbwZXBXORuYglzEXMnlv6wf90\nutvSP7Bt73C6cW36g+mai7YT5iJzEUuUi+aYW/pOoivgHNge76G7hPbwXh//R+urJR60bbkfdKcR\nfobu9LAtwMV0tw/csc0/lTYoWm+Z59KdhvZtujf4O+gN5kU3yvrX6U61/FN6A3fRHQA30Z1ydgVt\nkLkxca2jN1hca3sycCndm/lS4Mm9eRcyzUCFI+v987bex/fant/afmuk78/RvWG2tNfyCeDAcfsF\neDXd6XbfoDuVsOi+NRjX9xBgc+/5b9NV1m9rsfx+22ffBTbTXQM/3et5dNuPac9fwj0j/fcfa4BX\n0CXJ2+gKO2eO+d2+t213dJDIJ9Jd63xL2x/nAvvOdd/TDe72kbburwO/Pkv/U8e8hpf05l8OPHaG\n5a8Bvt+Os6nHh3v76F/ojtvb6b4VO6y37N50x/UtdN86/HZv3g50SeZrdMf/JcDebd7ooH9b/d7H\nxPiq9vu4A/hrYKflzgfL+cBcBOaipchFrxsT0+um6fuwNv8HbJ1LXtTrcy7wazNs78Ixy1/a3/90\nx+a36I7VY3vL7kp3nG6h+0buvwH3Gfl9XdnW+QXgca39GnqDZTJmwM2RGH+9bfu7dIPq7rbc+WA5\nH5iLwFy0qLmIOeSWkf5r27Zuo/vMcDnwspE+5qLt7IG5CMxFi52LZs0ts/zOXse9B/T2f7TeY+qX\nLw3WKudfoDsQ75qt/wJs72+As6q7vfZ81/XfgEdW1W/MP7LFke52nMdW1fNn7Tx++ZfQJdonL2hg\n0gpjLlpc7Vuzv6qqXxq4/CF0H8q25WwHaeKYixaXuUiaG3PR4vJ/tHuzuKRBkvxHutMf7093XexP\nquro5Y1q26QbMO9zdEnhU7P1n1TbY+KSppiLJof/0Gl7Zi6aHOYibc/MRZNje/wfbdWMuaQF91t0\np5J+le7623GDyq1Y6W4BeR3w8e05aUmrgLlI0kpgLpK0EpiLtGw8c0mSJEmSJEmDeeaSJEmSJEmS\nBrO4JEmSJEmSpMHWLHcAC22PPfaodevWLXcYkubp0ksv/VZVrV3uOIYyF0nbB3ORpJXAXCRpJZgp\nF213xaV169axcePG5Q5D0jwluXa5Y5gPc5G0fTAXSVoJzEWSVoKZcpGXxUmSJEmSJGkwi0uSJEmS\nJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JEmS\nJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBluz3AFI22rdiecuynqvefMzF2W9krZP\n5iJJK4X5SNK2MGdoMXjmkiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszikiRJ\nkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5J\nkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszi\nkiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTB\nLC5JkiRJkiRpMItLkiRJkiRJGszikqSJl+T3k1yR5AtJPpDkfkn2S3Jxkk1JPphkx9Z3p/Z8U5u/\nrreeV7f2K5Mc3ms/orVtSnLi0r9CSZPCfCRpEi1U7pK0ellckjTRkuwF/C6wvqoeDewAHAO8BXhb\nVT0CuBU4vi1yPHBra39b60eSA9pyjwKOAN6VZIckOwDvBI4EDgBe2PpK0lbMR5Im0ULlLkmrm8Ul\nSduDNcBPJVkD3B+4AXgacHabfxpwdJs+qj2nzT80SVr7mVV1Z1V9DdgEHNQem6rq6qr6IXBm6ytJ\n45iPJE2ihchdklYxi0uSJlpVXQ/8L+DrdB+EbgcuBW6rqrtat83AXm16L+C6tuxdrf/u/faRZaZr\nl6StmI8kTaIFzF2SVjGLS5ImWpJd6b5B2w94KPAAustIliOWE5JsTLJxy5YtyxGCpGW0UvKRuUjS\ntlis3GUuklYXi0uSJt3Tga9V1Zaq+hHwIeBJwC7t1G6AvYHr2/T1wD4Abf6DgZv77SPLTNd+L1V1\nUlWtr6r1a9euXYjXJmmyrIh8ZC6StI0WKndtxVwkrS4WlyRNuq8DBye5f7ve/1Dgi8Angee2PscB\nH23T57TntPmfqKpq7ce0O6DsB+wPfAa4BNi/3TFlR7oBLs9ZgtclafKYjyRNooXKXZJWsTWzd5Gk\nlauqLk5yNvBZ4C7gc8BJwLnAmUne2NpOboucDLwvySbgFrp/zqiqK5KcRfdh6i7gFVX1Y4AkrwTO\no7t7yilVdcVSvT5Jk8N8JGkSLVTukrS6WVySNPGq6rXAa0ear6a7s9Jo3x8Az5tmPW8C3jSmfQOw\nYf6RStremY8kTaKFyl2SVi8vi5MkSZIkSdJgsxaXkuyT5JNJvpjkiiS/19p3S3J+kqvaz11be5K8\nPcmmJJcleXxvXce1/lclOa7X/oQkl7dl3t6u9Z12G5IkSZIkSVoZ5nLm0l3AH1TVAcDBwCuSHACc\nCFxQVfsDF7TnAEfSDTy5P3AC8G7oCkV0p1o+ke70ytf2ikXvBl7WW27q1pfTbUOSJEmSJEkrwKzF\npaq6oao+26a/DXwJ2As4CjitdTsNOLpNHwWcXp2L6G5h+RDgcOD8qrqlqm4FzgeOaPN2rqqL2l0G\nTh9Z17htSJIkSZIkaQXYpjGXkqwDHgdcDOxZVTe0Wd8E9mzTewHX9Rbb3Npmat88pp0ZtiFJkiRJ\nkqQVYM7FpSQPBP4W+C9VdUd/XjvjqBY4tq3MtI0kJyTZmGTjli1bFjMMSZIkSZIk9cypuJTkvnSF\npTOq6kOt+cZ2SRvt502t/Xpgn97ie7e2mdr3HtM+0za2UlUnVdX6qlq/du3aubwkSZIkSZIkLYC5\n3C0uwMnAl6rqrb1Z5wBTd3w7Dvhor/3F7a5xBwO3t0vbzgMOS7JrG8j7MOC8Nu+OJAe3bb14ZF3j\ntiFJkiRJkqQVYM0c+jwJOBa4PMnnW9ufAG8GzkpyPHAt8Pw2bwPwDGAT8D3gpQBVdUuSNwCXtH6v\nr6pb2vTLgVOBnwI+3h7MsA1JkiRJkiStALMWl6rq00CmmX3omP4FvGKadZ0CnDKmfSPw6DHtN4/b\nhiRJkiRJklaGbbpbnCRJkiRJktRncUmSJEmSJEmDWVySJEmSJEnSYBaXJEmSJEmSNJjFJUmSJEmS\nJA1mcUmSJEmSJEmDWVySJEmSJEnSYBaXJEmSJEmSNJjFJUmSJEmSJA1mcUmSJEmSJEmDWVySJEmS\nJEnSYBaXJEmSJEmSNJjFJUmSJEmSJA1mcUmSJEmSJEmDWVySJEmSJEnSYBaXJEmSJEmSNJjFJUmS\nJEmSJA1mcUmSJEmSJEmDWVySJEmSJEnSYBaXJEmSJEmSNJjFJUmSJEmSJA1mcUmSJEmSJEmDWVyS\nJEmSJEnSYBaXJEmSJEmSNJjFJUmSJEmSJA1mcUmSJEmSJEmDWVySJEmSJEnSYBaXJEmSJEmSNJjF\nJUmSJEmSJA1mcUmSJEmSJEmDWVySJEmSJEnSYBaXJEmSJEmSNJjFJUmSJEmSJA1mcUmSJEmSJEmD\nWVySJEmSJEnSYBaXJEmSJEmSNJjFJUmSJEmSJA1mcUmSJEmSJEmDWVySNPGS7JLk7CRfTvKlJL+U\nZLck5ye5qv3ctfVNkrcn2ZTksiSP763nuNb/qiTH9dqfkOTytszbk2Q5Xqeklc98JGkSLVTukrR6\nWVyStD34S+Dvq+rngccCXwJOBC6oqv2BC9pzgCOB/dvjBODdAEl2A14LPBE4CHjt1Ieo1udlveWO\nWILXJGkymY8kTaJ55y5Jq5vFJUkTLcmDgV8BTgaoqh9W1W3AUcBprdtpwNFt+ijg9OpcBOyS5CHA\n4cD5VXVLVd0KnA8c0ebtXFUXVVUBp/fWJUl3Mx9JmkQLmLskrWIWlyRNuv2ALcBfJ/lckvcmeQCw\nZ1Xd0Pp8E9izTe8FXNdbfnNrm6l985h2SRplPpI0iRYqd0laxdYsdwCSNE9rgMcD/7mqLk7yl9xz\n2jYAVVVJarEDSXIC3enh7Lvvvou9OUkrz4rIR+YiSdtoUXKXuUgLZd2J5y53CNvkmjc/c7lDWBae\nuSRp0m0GNlfVxe352XQfkG6cOkW7/bypzb8e2Ke3/N6tbab2vce030tVnVRV66tq/dq1a+f1oiRN\npBWRj8xFkrbRQuWurZiLpNXF4pKkiVZV3wSuS/JzrelQ4IvAOcDUHZaOAz7aps8BXtzudHIwcHs7\n5fs84LAku7aBcw8Dzmvz7khycLsr04t765Kku5mPJE2iBcxdklYxL4uTtD34z8AZSXYErgZeSlc8\nPyvJ8cC1wPNb3w3AM4BNwPdaX6rqliRvAC5p/V5fVbe06ZcDpwI/BXy8PSRpHPORpEk079wlaXWb\ntbiU5BTgWcBNVfXo1vY6utvgbmnd/qSqNrR5rwaOB34M/G5Vndfaj6C7xeUOwHur6s2tfT/gTGB3\n4FLg2Kr6YZKd6O6C8gTgZuAFVXXNArxmSduZqvo8sH7MrEPH9C3gFdOs5xTglDHtG4FHzzNMSauA\n+UjSJFqo3CVp9ZrLZXGnAkeMaX9bVR3YHlOFpQOAY4BHtWXelWSHJDsA7wSOBA4AXtj6ArylresR\nwK10hSnaz1tb+9taP0mSJEmSJK0gsxaXqupTwC2z9WuOAs6sqjur6mt0p0oe1B6bqurqqvoh3ZlK\nR7XxAp5GN2gcwGnA0b11ndamzwYObf0lSZIkSZK0QsxnQO9XJrksySltsEmAvYDren02t7bp2ncH\nbququ0bat1pXm3976y9JkiRJkqQVYmhx6d3AzwIHAjcAf7FgEQ2Q5IQkG5Ns3LJly+wLSJIkSZIk\naUEMKi5V1Y1V9eOq+gnwf+guewO4Htin13Xv1jZd+83ALknWjLRvta42/8Gt/7h4Tqqq9VW1fu3a\ntUNekiRJkiRJkgYYVFxK8pDe0/8IfKFNnwMck2Sndhe4/YHP0N1Kd/8k+7XbWx4DnNPuNPBJ4Llt\n+eOAj/bWdVybfi7widZfkiRJkiRJK8Sa2Tok+QBwCLBHks3Aa4FDkhwIFHAN8FsAVXVFkrOALwJ3\nAa+oqh+39bwSOA/YATilqq5om/hj4MwkbwQ+B5zc2k8G3pdkE92A4sfM+9VKkiRJkiRpQc1aXKqq\nF45pPnlM21T/NwFvGtO+Adgwpv1q7rmsrt/+A+B5s8UnSZIkSZKk5TOfu8VJkiRJkiRplbO4JEmS\nJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uS\nJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4\nJEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkw\ni0uSJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmS\nBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmS\nJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmS\nJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JGm7kGSHJJ9L8rH2\nfL8kFyfZlOSDSXZs7Tu155va/HW9dby6tV+Z5PBe+xGtbVOSE5f6tUmaHOYiSZNqIfKXpNXL4pKk\n7cXvAV/qPX8L8LaqegRwK3B8az8euLW1v631I8kBwDHAo4AjgHe1D1k7AO8EjgQOAF7Y+krSOOYi\nSZNqXvlL0upmcUnSxEuyN/BM4L3teYCnAWe3LqcBR7fpo9pz2vxDW/+jgDOr6s6q+hqwCTioPTZV\n1dVV9UPgzNZXkrZiLpI0qRYof0laxSwuSdoe/G/gj4CftOe7A7dV1V3t+WZgrza9F3AdQJt/e+t/\nd/vIMtO1S9Ioc5GkSbUQ+UvSKmZxSdJES/Is4KaqunQFxHJCko1JNm7ZsmW5w5G0hMxFkibVYuUv\nc5G0usxaXEpySpKbknyh17ZbkvOTXNV+7trak+TtbXC3y5I8vrfMca3/VUmO67U/IcnlbZm3T51S\nOd02JGnEk4BfS3IN3WUiT0grKewAABF2SURBVAP+EtglyZrWZ2/g+jZ9PbAPQJv/YODmfvvIMtO1\n30tVnVRV66tq/dq1a+f/yiRNEnORpEm1UPlrK+YiaXWZy5lLp9INKNl3InBBVe0PXNCeQzfI5P7t\ncQLwbugKRcBrgSfSjRnw2l6x6N3Ay3rLHTHLNiTpblX16qrau6rW0Q2C+4mqehHwSeC5rdtxwEfb\n9DntOW3+J6qqWvsx7Q4o+9Hlo88AlwD7tzum7Ni2cc4SvDRJE8RcJGlSLWD+krSKzVpcqqpPAbeM\nNPcHcRsd3O306lxEV+1+CHA4cH5V3VJVtwLnA0e0eTtX1UUtIZ3O+IHi+tuQpLn4Y+BVSTbRjQNw\ncms/Gdi9tb+KVriuqiuAs4AvAn8PvKKqftzGEnglcB7dHVTOan0laS7MRZIm1TblL0mr25rZu4y1\nZ1Xd0Ka/CezZprd1EMq92vRo+0zbkKSxqupC4MI2fTXdmZKjfX4APG+a5d8EvGlM+wZgwwKGKmk7\nZi6SNKnmm78krV7zHtC7nXG0qKdBzrYNB4uTJEmSJElaHkOLSze2S9poP29q7ds6COX1bXq0faZt\n3IuDxUmSJEmSJC2PocWl/iBuo4O7vbjdNe5g4PZ2adt5wGFJdm0DeR8GnNfm3ZHk4HaXuBczfqC4\n/jYkSZIkSZK0Qsw65lKSDwCHAHsk2Ux317c3A2clOR64Fnh+674BeAawCfge8FKAqrolyRvo7nQC\n8Pqqmhok/OV0d6T7KeDj7cEM25AkSZIkSdIKMWtxqapeOM2sQ8f0LeAV06znFOCUMe0bgUePab95\n3DYkSZIkSZK0csx7QG9JkiRJkiStXhaXJEmSJEmSNJjFJUmSJEmSJA1mcUmSJEmSJEmDWVySJEmS\nJEnSYBaXJEmSJEmSNJjFJUmSJEmSJA1mcUmSJEmSJEmDWVySJEmSJEnSYBaXJEmSJEmSNJjFJUmS\nJEmSJA1mcUmSJEmSJEmDWVySJEmSJEnSYBaXJEmSJEmSNJjFJUmSJEmSJA1mcUmSJEmSJEmDWVyS\nJEmSJEnSYBaXJEmSJEmSNJjFJUmSJEmSJA22ZrkDkCRJkiQJYN2J5y7Keq958zMXZb2LabH2hSbT\nSn9veOaSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JEmS\nJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uS\nJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4\nJEmSJEmSpMEsLkmSJEmSJGkwi0uSJEmSJEkazOKSJEmSJEmSBrO4JEmSJEmSpMEsLkmSJEmSJGkw\ni0uSJlqSfZJ8MskXk1yR5Pda+25Jzk9yVfu5a2tPkrcn2ZTksiSP763ruNb/qiTH9dqfkOTytszb\nk2TpX6mklc58JGkSLWTukrR6WVySNOnuAv6gqg4ADgZekeQA4ETggqraH7igPQc4Eti/PU4A3g3d\nByjgtcATgYOA1059iGp9XtZb7ogleF2SJo/5SNIkWpDcJWl1s7gkaaJV1Q1V9dk2/W3gS8BewFHA\naa3bacDRbfoo4PTqXATskuQhwOHA+VV1S1XdCpwPHNHm7VxVF1VVAaf31iVJdzMfSZpEC5i7JK1i\n8youJbmmnZr9+SQbW5unfktaFknWAY8DLgb2rKob2qxvAnu26b2A63qLbW5tM7VvHtMuSdMyH0ma\nRPPMXZJWsYU4c+lXq+rAqlrfnnvqt6Qll+SBwN8C/6Wq7ujPa9/w1xLEcEKSjUk2btmyZbE3J2mF\nWu58ZC6SNMRC5y5zkbS6LMZlcZ76LWlJJbkv3YehM6rqQ635xqlTtNvPm1r79cA+vcX3bm0zte89\npv1equqkqlpfVevXrl07vxclaSKthHxkLpK0rRYod23FXCStLvMtLhXwD0kuTXJCa/PUb0lLpl0u\nezLwpap6a2/WOcDUZbbHAR/ttb+4Xap7MHB7y1nnAYcl2bWdPXkYcF6bd0eSg9u2XtxblyTdzXwk\naRItYO6StIqtmefyT66q65P8NHB+ki/3Z1ZVJVmSS1HoLrVj3333XezNSVpZngQcC1ye5POt7U+A\nNwNnJTkeuBZ4fpu3AXgGsAn4HvBSgKq6JckbgEtav9dX1S1t+uXAqcBPAR9vD0kaZT6SNIkWJHdJ\nWt3mVVyqquvbz5uSfJhuzKQbkzykqm7YhlO/Dxlpv5BtvBQFOAlg/fr1i17MkrRyVNWngekG+z90\nTP8CXjHNuk4BThnTvhF49DzClLQKmI8kTaKFzF2SVq/Bl8UleUCSB01N052y/QU89VuSJEmSJGnV\nmM+ZS3sCH+7qPqwB/qaq/j7JJXjqtyRJkiRJ0qowuLhUVVcDjx3TfjOe+i1JkiRJkrQqzPducZIk\nSZIkSVrFLC5JkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpMItL\nkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgaz\nuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRp\nMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszikiRJkiRJ\nkgazuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJ\nkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszikiRJ\nkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5J\nkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpsBVfXEpyRJIrk2xK\ncuJyxyNpdTIXSVopzEeSVgJzkaS+FV1cSrID8E7gSOAA4IVJDljeqCStNuYiSSuF+UjSSmAukjRq\nRReXgIOATVV1dVX9EDgTOGqZY5K0+piLJK0U5iNJK4G5SNJWVnpxaS/gut7zza1NkpaSuUjSSmE+\nkrQSmIskbWXNcgewEJKcAJzQnn4nyZXLGQ+wB/CtZY5hWxgvkLcs9Brv5v4d5mHLHcC2MhfNm/Fi\nLhqxEmI2F83fSvg9botJixfMR4ttJcRrLppvPNMfzyvh9zsfKyb+gTljxcQ/wNjYFzF3LrQ9gG9t\nY7zT5qKVXly6Htin93zv1raVqjoJOGmpgppNko1VtX6545gr411cxrtdMBctAeNdXJMWL0xmzEtg\n1nxkLpqfSYsXJi9m490uTFwums6k/36Nf/lMcuyw8PGv9MviLgH2T7Jfkh2BY4BzljkmSauPuUjS\nSmE+krQSmIskbWVFn7lUVXcleSVwHrADcEpVXbHMYUlaZcxFklYK85GklcBcJGnUii4uAVTVBmDD\ncsexjVb86Z8jjHdxGe92wFy0JIx3cU1avDCZMS+6CcxHk/Z7nLR4YfJiNt7twATmoulM+u/X+JfP\nJMcOCxx/qmoh1ydJkiRJkqRVZKWPuSRJkiRJkqQVzOLSAkiyW5Lzk1zVfu46Q9+dk2xO8o6ljHEk\nhlnjTXJgkn9LckWSy5K8YBniPCLJlUk2JTlxzPydknywzb84ybqljnEkntnifVWSL7b9eUGSZb2l\n7Gzx9vo9J0klmdg7IawW5qJFi9NctIjMRdsfc9GixWkuWkTmou3bXPNSkr9PcluSj42079feV5va\n+2zHpYn87u3PNf7jWp+rkhzXa7+wHd+fb4+fXoKYB+esJK9u7VcmOXyxYx1naPxJ1iX5fm9fv2ep\nY29xzBb/ryT5bJK7kjx3ZN7Y42hWVeVjng/gfwAntukTgbfM0Pcvgb8B3rGS4wUeCezfph8K3ADs\nsoQx7gB8FXg4sCPw78ABI31eDrynTR8DfHAZ9+lc4v1V4P5t+ndWeryt34OATwEXAeuXK14fc/69\nmosWPkZz0TLH2/qZiyboYS5alBjNRcscb+tnLprQx1zzEnAo8GzgYyPtZwHHtOn3AL+z0uIHdgOu\nbj93bdO7tnkXLuUxO5+cBRzQ+u8E7NfWs8MS7+/5xL8O+MJSxjsw/nXAY4DTgefO5Tia7eGZSwvj\nKOC0Nn0acPS4TkmeAOwJ/MMSxTWdWeOtqq9U1VVt+hvATcDaJYsQDgI2VdXVVfVD4Ey6uPv6r+Ns\n4NAkWcIY+2aNt6o+WVXfa08vAvZe4hj75rJ/Ad4AvAX4wVIGp8HMRQvPXLS4zEXbJ3PRwjMXLS5z\n0fZvTnmpqi4Avt1va++jp9G9r2ZcfhHNJf7DgfOr6paquhU4HzhiieIbNZ+cdRRwZlXdWVVfAza1\n9S2lScu5o+aSg6+pqsuAn4wsO/g4sri0MPasqhva9DfpPihtJcl9gL8A/nApA5vGrPH2JTmIruL5\n1cUOrGcv4Lre882tbWyfqroLuB3YfUmiu7e5xNt3PPDxRY1oZrPGm+TxwD5Vde5SBqZ5MRctPHPR\n4jIXbZ/MRQvPXLS4zEXbv216n4/YHbitva9g9uN5Mcwl/tmO479ul2m9ZgmKIPPJWduaPxbDfHPu\nfkk+l+SfkjxlsYMdYz77cPCya+a4gVUvyT8CPzNm1p/2n1RVJRl3C76XAxuqavNSFDQXIN6p9TwE\neB9wXFWNVjU1QJLfANYDT13uWKbTPvS/FXjJMoeiEeYic9FCMRdpPsxF5qKFYi7SQlmo9/lyWeT4\nX1RV1yd5EPC3wLF0l0Np4d0A7FtVN7czdD+S5FFVdcdyB7bYLC7NUVU9fbp5SW5M8pCquqF96Lhp\nTLdfAp6S5OXAA4Edk3ynqqYdMHCZ4yXJzsC5wJ9W1UWLEecMrgf26T3fu7WN67M5yRrgwcDNSxPe\nvcwlXpI8ne4PxFOr6s4lim2c2eJ9EPBo4ML2of9ngHOS/FpVbVyyKHUv5iJz0SzMRVoS5iJz0SzM\nRVpyC/E+n8bNwC5J1rQzVMYez/O1APFfDxzSe7433VhLVNX17ee3k/wN3WVTi1lcmk/OmlP+WGSD\n46+qAu4EqKpLk3yVbty+pcwV89mH0x5Hs/GyuIVxDjA1ivpxwEdHO1TVi6pq36paR3cK+OmL9QFq\nDmaNN90dED5MF+fZo/OXwCXA/unuzLAj3SBp54z06b+O5wKfaG/m5TBrvEkeB/wV8GtVtS1/0BbD\njPFW1e1VtUdVrWvH7EV0cfsBamUzFy08c9HiMhdtn8xFC89ctLjMRdu/Wd/n02nvo0/Sva+2efkF\nMpf4zwMOS7JrurvJHQacl2RNkj0AktwXeBbwhUWOdz456xzgmHR3Y9sP2B/4zCLHO2pw/EnWJtkB\nIMnD6eK/eoninjKX+Kcz9jia05K1jKOYby8PumsrLwCuAv4R2K21rwfeO6b/S1jeu6LMGi/wG8CP\ngM/3HgcucZzPAL5CN6bBn7a219P9MQe4H/B/6QZ5+wzw8GU+DmaL9x+BG3v785yVHO9I3wvxrigr\n/mEuWrQ4zUXLGO9IX3PRBDzMRYsWp7loGeMd6WsumrDHXPMS8M/AFuD7dGPNHN7aH97eV5va+2yn\nFRr/f2oxbgJe2toeAFwKXAZcQXeXzkW/+9p8chbdGY1fBa4EjlymY2ZQ/MBz2n7+PPBZ4NkrNP5f\nbMf4d+nOGLtipuNoLo+0hSVJkiRJkqRt5mVxkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5J\nkiRJkiRpMItLkiRJkiRJGszikiRJkiRJkgazuCRJkiRJkqTBLC5JkiRJkiRpsP8HqVeE27Z4k2IA\nAAAASUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3oAAAE/CAYAAAAQWbGOAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n6E1d/LSnVgAAAABJRU5ErkJggg==\n",
            "text/plain": [
              "<Figure size 1080x360 with 3 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "fa-OxGPpVq9o"
      },
      "source": [
        "Observation: Still a lot of zeros in the activation"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "7F2s8h7PVurn",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 119
        },
        "outputId": "5a88eb24-cb73-4adb-eccb-a26f6932d8b1"
      },
      "source": [
        "# Instantiate a neural net model\n",
        "activation_func = torch.tanh\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Apply initialization\n",
        "initialization='xavier'\n",
        "model = apply_initialization(model, initialization)\n",
        "\n",
        "# Define optimizer: Choose SGD for now\n",
        "learning_rate = 0.01\n",
        "optimizer = torch.optim.SGD(model.parameters(), lr=learning_rate, momentum=0.9)\n",
        "\n",
        "# Run the training loop \n",
        "train_accs, test_accs, train_losses, test_losses = train_model(model, optimizer, train_dl, test_dl, epochs=10, print_every=2, debug=False)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "stream",
          "text": [
            "Using cuda\n",
            "Epoch 0, Train acc: 90.55%, Test acc: 94.71%\n",
            "Epoch 2, Train acc: 97.30%, Test acc: 96.86%\n",
            "Epoch 4, Train acc: 98.74%, Test acc: 97.22%\n",
            "Epoch 6, Train acc: 99.47%, Test acc: 97.36%\n",
            "Epoch 8, Train acc: 99.83%, Test acc: 97.56%\n"
          ],
          "name": "stdout"
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "SpRFA_wDJ0MS",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 573
        },
        "outputId": "083a180e-6ca7-45be-b37c-39c619a330c6"
      },
      "source": [
        "caption=\"Xavier Initialization\"\n",
        "plot_acc_loss(train_accs, test_accs, train_losses, test_losses, caption)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYgAAAEWCAYAAAB8LwAVAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nJ1YAAAAASUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYgAAAEWCAYAAAB8LwAVAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nsgRhjDHGr/8HZIltFS5ssGIAAAAASUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "eVjNjWpqV0yZ",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 1000
        },
        "outputId": "49716e88-a77c-47a9-dcb9-845eab9b0f6f"
      },
      "source": [
        "# Try with debug on for a few epoch\n",
        "\n",
        "# Instantiate a neural net model\n",
        "activation_func = torch.tanh\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Apply initialization\n",
        "initialization='xavier'\n",
        "model = apply_initialization(model, initialization)\n",
        "\n",
        "# Define optimizer: Choose SGD for now\n",
        "learning_rate = 0.01\n",
        "optimizer = torch.optim.SGD(model.parameters(), lr=learning_rate, momentum=0.9)\n",
        "\n",
        "# Run the training loop \n",
        "train_accs, test_accs, train_losses, test_losses = train_model(model, optimizer, train_dl, test_dl, epochs=2, print_every=2, debug=True)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJAAAAE/CAYAAAAZojm1AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nZmZmZmZmA/0fQRYKSwg9+E8AAAAASUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "stream",
          "text": [
            "Using cuda\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJcAAAE/CAYAAAD7fiLMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nTkSuQmCC\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3UAAAE/CAYAAADhUuoDAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nJEmS1GMmdZIkSZLUYyZ1kiRJktRj/z+DznH6PCXVRQAAAABJRU5ErkJggg==\n",
            "text/plain": [
              "<Figure size 1080x360 with 3 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "stream",
          "text": [
            "Epoch 0, Train acc: 90.27%, Test acc: 94.74%\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJcAAAE/CAYAAAD7fiLMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n/8C8e9XD7v0AAAAASUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3MAAAE/CAYAAADsTJpEAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
            "text/plain": [
              "<Figure size 1080x360 with 3 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "kQgymj0Z3zT6"
      },
      "source": [
        "Compare to network trained with ReLU and with He Initialization"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "nX9bNKc147Jn",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 119
        },
        "outputId": "3672190b-18f3-4b01-e2cf-9d248a62093f"
      },
      "source": [
        "# Instantiate a neural net model\n",
        "activation_func = torch.relu\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Apply initialization\n",
        "initialization='he'\n",
        "model = apply_initialization(model, initialization)\n",
        "\n",
        "# Define optimizer: Choose SGD for now\n",
        "learning_rate = 0.01\n",
        "optimizer = torch.optim.SGD(model.parameters(), lr=learning_rate, momentum=0.9)\n",
        "\n",
        "# Run the training loop \n",
        "train_accs, test_accs, train_losses, test_losses = train_model(model, optimizer, train_dl, test_dl, epochs=10, print_every=2, debug=False)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "stream",
          "text": [
            "Using cuda\n",
            "Epoch 0, Train acc: 91.36%, Test acc: 94.62%\n",
            "Epoch 2, Train acc: 98.15%, Test acc: 96.97%\n",
            "Epoch 4, Train acc: 99.23%, Test acc: 97.50%\n",
            "Epoch 6, Train acc: 99.73%, Test acc: 97.61%\n",
            "Epoch 8, Train acc: 99.92%, Test acc: 97.77%\n"
          ],
          "name": "stdout"
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "AzvE_MMsKClq",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 573
        },
        "outputId": "f8561e10-97a7-4e0f-9bae-2c578d815fdf"
      },
      "source": [
        "caption=\"He Initialization (ReLU MLP)\"\n",
        "plot_acc_loss(train_accs, test_accs, train_losses, test_losses, caption)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAZoAAAEWCAYAAABfdFHAAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nTZ8AAAAASUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAY4AAAEWCAYAAABxMXBSAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nJw7nnHNx8cThnHMuLp44nHPOxeX/ARw2l1uRe+UUAAAAAElFTkSuQmCC\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "RX4AnJKeKHUK",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 1000
        },
        "outputId": "b9dfe872-b62f-4b84-b80a-10b719263223"
      },
      "source": [
        "# Try with debug on for a few epoch\n",
        "\n",
        "# Instantiate a neural net model\n",
        "activation_func = torch.relu\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Apply initialization\n",
        "initialization='he'\n",
        "model = apply_initialization(model, initialization)\n",
        "\n",
        "# Define optimizer: Choose SGD for now\n",
        "learning_rate = 0.01\n",
        "optimizer = torch.optim.SGD(model.parameters(), lr=learning_rate, momentum=0.9)\n",
        "\n",
        "# Run the training loop \n",
        "train_accs, test_accs, train_losses, test_losses = train_model(model, optimizer, train_dl, test_dl, epochs=2, print_every=2, debug=True)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJAAAAE/CAYAAAAZojm1AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nRU5ErkJggg==\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "stream",
          "text": [
            "Using cuda\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJcAAAE/CAYAAAD7fiLMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nxSVJkiRJkiRNzOKSJEmSJEmSJvb/AX30+yaOSU3UAAAAAElFTkSuQmCC\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3kAAAE/CAYAAAD7bgqNAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
            "text/plain": [
              "<Figure size 1080x360 with 3 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "stream",
          "text": [
            "Epoch 0, Train acc: 91.39%, Test acc: 94.88%\n"
          ],
          "name": "stdout"
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAABJcAAAE/CAYAAAD7fiLMAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAADh0RVh0U29mdHdhcmUAbWF0cGxvdGxpYiB2ZXJzaW9uMy4xLjIsIGh0\ndHA6Ly9tYXRwbG90bGliLm9yZy8li6FKAAAgAElEQVR4nOzde7heZX3n//enRNR64pQymKChNdpB\nf4qQQVqtpaIQ0AqdKoU6Eh0qOsKMVudXoWMHK/KrdqYyelXpoKSApQL1UFON0vwQau0UJAgFASkB\nQRI5RMJBoWKD3/lj3VtWHvYpT3b23tn7/bqude21vve9Ts9+9r3X833Wfa9UFZIkSZIkSdIwfmam\nD0CSJEmSJEk7LpNLkiRJkiRJGprJJUmSJEmSJA3N5JIkSZIkSZKGZnJJkiRJkiRJQzO5JEmSJEmS\npKGZXNoOktyW5JVDrPefktyd5IdJdt8exzasJH+W5A8mWfecJB/Yjsfy6SRHba/tzzZJfj3JhTN9\nHIOSVJLnzPRxaGy2RbZFUynJC5P8n5k+jkHDvs81fWyLbIumkm2RhmVbZFs0lfyM9njzLrmU5Jgk\nVyR5KMk9bf7tSTLDx/UE4MPAoVX11Kq6dxu3d0qSLw/Ebh4jdsxE26uqt1XVadtyTL19Dv2GT/JC\n4EXAF9rym5J8fSqOayol2S3J59v77PYkvz1B/dOSXJdkc5L39cuq6m+A57dzH2v925L8S/unNzL9\n6dSczdRI8rtJ7kryYJKVSZ4408c0k2yLbIumQ5KTkqxN8kiScyao+8QkZ7c26wdJrkly+Eh5VV0L\n3J/k18fZxmVJfjTQFv3N1J3Rtkvy2+0cH0ry10l2m+ljmkm2RbZF29tEbcsY6/xFkjvbNcM/J/md\nkTLbornJtsi2aDqM17ZMsN7S1qb8xUjMz2iPN6+SS0neDXwE+B/AvwH2BN4GvBTYeYx1dpqmw9sT\neBJw/daumM7g7/JrwC+PHH+SvYAnAC8eiD2n1d1RvBU4v6pqpg8ExnztAT4G/Jju9/oG4Mwkzx9n\nU+uA3wO+NEb5p4ETJjicX2//9EamkyaoP22SHAacDBwCPBv4eeAPZ/SgZpBtkW3RVBunLfoe8AFg\n5SQ2swC4A/hV4BnAe4GLkizp1Tmf7tzHc9JAWzTmB8Dp1trh/w28ke69/jDw8Rk9qBlkW2RbNNXG\neO0n07YM+iNgSVU9HXgt8IEkB/TKbYvmENsi26KpNs510URty1g+Blw5StzPaD3zJrmU5BnA+4G3\nV9VnquoH1bm6qt5QVY+0euckOTPJ6iQPAb+W5NVJrm7ZvDsycGdJkjem++bh3iT/baDswHTfGj+Y\n7nbKD49ybM8FbmqL9yf5aov/cpIrkzzQfv5yb53Lkpye5B/o/iH9/MBmr6RrqPZry78CXNr204/d\nUlXfa9v8xSRrkmxKclOSo3v72+I2yiS/ly7r+70kv5PHZ7p3TfKldN9QXZHkF9p6I43kP6XL3P5W\nkj2SfDHJ/W3ffz9GYwBwOPB3Y5RtIcmbk9zYjuHWJG/tlX0rvW+8kjwhyfeTvLgtH5Tk/7Rj+qck\nB/fqjvvaJ3kK8JvAH1TVD6vq68AquguIUVXVuVX1ZeAHY1S5DHj1ZM57ULpvDv4hyZ+299K3kxzS\nK39mklXttV+X5C29sp2S/H6SW9rreFWSvXubf2W6b1buT/KxZMxvl1YAZ1fV9VV1H3Aa8KZhzmdH\nZ1tkWzRdbRFAVX2uqv4amPCb1qp6qKreV1W3VdVPquqLwHeA/kXXZcAhGeJbrSQHJ1nf2pTvp/s2\n7w298mckOS/JxvY+fm//9U/ylt7reEOS/Xub3y/Jte09emGSJ41xGG8A/qaqvlZVPwT+APj3SZ62\nteezo7Mtsi2arrZokm0LA+tcP/IeBKpNv9Crchm2RXOCbZFt0XS1RTCptmW04z0GuB+4ZJTiy/Az\n2mOqal5MwHJgM7BggnrnAA/QZcp/hi5TfTDw/7TlFwJ3A0e1+vsCPwReDjyR7rbJzcArW/k/Am9s\n808FDhpjv0vo3twL2vJuwH10CYkFwLFtefdWfhnwXeD5rfwJo2zzUuB32/yfAv8ROH0gtrLNP4Xu\nW6U3t+29GPg+sG/vdflA77W8q+37Z4G/aMf+nF7de4ED27bOBy7oHddP67blPwL+jK6hfQJdg5pR\nzucpbd2FvdibgK+P8Zq+mq6xCN23ZQ8D+7ey3wMu7NU9EriuzS9qx39E+52/qi0vnMxr3167hwdi\n/5XuImKi9+lfAO8bJb5bO/enj7HebSPvuVHK3kT3nvzd9vr+Ft17fLdW/jW6b8ueRPdPbSPwilb2\n/wLXAc9rr+OLeOw9WMAXgV2AZ7X1lo9xDP8E/FZveY+2/u4z3TZM94RtkW3RNLVFA8fwAeCcrXyv\n7gn8CPjFgfiDwAvHWOcy4HfGKDuY7j35Ybr36K8CDwHPa+Xn0d1O/zS69+E/A8e3stcDG4B/117H\n5wDPbmW3Ad8Ankn3fr0ReNsYx/AF4D0DsR8CB8x02zDdE7ZFtkUz0Ba1+qO2LaPU+3g7xgK+CTx1\noNy2aA5M2BbZFk1zW8QEbctA3afTtQGLgfcBfzFQ7me03jRv7lyie6G+X1WbRwK9rOe/JHl5r+4X\nquofqvt25UdVdVlVXdeWr6W7/e1XW93XAV+s7puHR+i+efhJb1v/CjwnyR7V3cVy+SSP99XAzVX1\nqaraXFWfBr4N9G/pPae6LOPmqvrXUbbxd3QNKnSNwd+3qR8byTC/Britqv68be9q4LN0/0QHHQ38\nedv3w3R/aIM+X1XfaK/3+TyWiR/NvwJ70f1z/teq+vtq7+4Bu7SfY93ds4Wq+lJV3VKdvwP+lu6c\noWtsj0jy9Lb8RuBTbf4/AKuranX7na8B1tI1ZCPGe+2fSnfB0/cA3UXKsEbOeZdx6vx1ez+PTG/p\nld0D/K/2+l5I9+3Iq1uG+6V0Fzg/qqprgE8Cx7X1fgd4b1Xd1F7Hf6ot+5p/sKrur6rv0v2jHOv3\n/FS612DEyPy8+4YO2yLboulri4aWboyJ84Fzq+rbA8U/YPy26KMDbdHgWBB/UFWPtNfiS8DR6boC\nHAOcUt231rcBf8Jjd3z+DvDHVXVlex3XVdXt/X1W1feqahPwN0y+LYJtb593VLZFtkXT3hZN0LYM\nHu/b6f42fwX4HPDIQBXbornBtsi2aFrbokm0LX2n0d3Zs36Mcj+j9cyn5NK9wB5JFowEquqXq2qX\nVtZ/Le7or5jkJUkuTXd77AN0fYD3aMXP7NevqofYsvvB8cBzgW+32yZfM8njfSZw+0DsdrqM7ajH\nOYqvAS9LN0Dgwqq6Gfg/dP18dwNewGN9eZ8NvKT/xqe7ZfffjHFs/X2Pdhx39eYfpnvjjuV/0I05\n9Lft1siTx6h3f/s5qTd7ksOTXN5uJbyfruHZA6C620z/AfjNJLvQ3cp5flv12cDrB16Ll9E1riPG\ne+1/SJfl7ns6rfFJcn0eG9DtVx639uhGzvn+ceocVVW79KZP9Mo2DPwzuJ3u9/hMYFNV/WCgbOR9\ntjdwyzj7nOzvefA1GZmf1D+hOca2yLZoutqiiY7ry722qN8l5GfoLuR+DIw2LsDTGL8t+i8DbVH/\nKTb3tffmiJG2aA+6b+1uHyjb3m0R9Nrneca2yLZoWtuisdqWsdqidlyPVje8wGLgPw1s0rZobrAt\nsi2a9uui0dqWwbYoyX7AK4EzxtmUn9F65lNy6R/pspJHTqLuYEb2L+nGzNm7qp5Bd3vgSL/FO+l+\nuQAk+Vngp4+orKqbq+pY4OeADwGfSTcmz0S+R/cH1PcsultxxzrOQf9IN3DiW+j+SKmqB9u23wJ8\nr6q+0+reAfzdwBv/qVU1+I8cunNe3Fvee5Q6k1bdN0PvrqqfpxtY7V3p9Tft1XuI7o/ouRNtM10f\n/M8C/xPYs/2DWs1jvzeAc+ky4K8H/rGqRl7bO4BPDbwWT6mqD/YPZ5zd/zOwIMnSXuxFtIEAq+r5\n9diAbn8/0bk0/5buW4vBO6Ima1GyRV/bZ9G9D74H7JYt+/j332d3MEE/5Em6nu41GPEi4O7axidu\n7KBsi7AtYnraonFV1eG9tuj8drwBzqbrtvKbg9/6JVlEN7jqTY/b4OTsOvC+G2mLvk/3DemzB8q2\na1uU5Ofpukv88xRse0djW4RtEdPUFo3XtozWFo1iAb02wLZoTrEtwraImbsu+mnbMkpbdDBdt8jv\nJrmLbpiT30zyzd76fkbrmTfJpaq6n27k848neV2SpyX5mZaRnKgheRpd5vBHSQ4E+o+V/wzwmiQv\nS7Iz3YB0/UH//kOShVX1Ex7LaPZvyRzLauC56R5TuiDJb9H1Hf7iZM4XoKr+he5WwXfR3Wo54ust\n1n8CwRfb/t6YbuC0JyT5d0n+7Sibvgh4c5J/2xrqPxilznjupjfAWpLXJHlO+8N6AHiUsV+j1Tx2\nu2tvE3lSf6K74HgiXR/TzekeeXvowHp/DewPvIOuf/2IvwB+Pclh6QZLe1K6wR8XMwmtgf0c8P4k\nT0nyUrp/mJ8aa532ej+J7r2zoO2z/xSMXwW+PPrak/JzwH9p+3k9XUO4uqruoPum5I/aPl9I903O\nyGM2Pwmclu7xm0nywiS7j7qH8Z0HHJ9k3/YtxHvp+n3PO7ZFtkVMU1vUDmhBO46dgJFtLBhnlTPp\n2odfb7+3Qb8KfLUeGwxzGH+YZOd0d26+BvirqnqU7vd5evubeDbde6PfFv3XJAe0tug5rc7WOp/u\nNf2V9iHi/cDnBr4ZnBdsi2yLmMa2iInblv7B/1y6x9I/te3vMLpxbfqD6doWzRG2RbZFTFNbNMm2\npe8sugTOfm36M7outIf16vgZra+medC2mZ7obiP8Bt3tYRuBK+geH7hzKz+HNihab53X0d2G9gO6\nP/A/pTeYF90o69+lu9Xyv9EbuIvuDXAP3S1n19MGmRvluJbQGyyuxV4GXEX3x3wV8LJe2WWMMVDh\nwHb/qG13/17s6BZ760Dd59H9wWxs5/JVYL/RXhfgFLrb7b5Hdyth0X1rMFrdg4H1veW30WXW72/H\n8rvtNXsIWE/XB36s83lBex3Tlt/EYyP996cFwIl0jeT9dImdC0b53X6y7XdwkMiX0PV13tRejy8B\nz5rsa083uNtft21/F/jtCeqfM8o5vKlXfh3wonHWvw34l/Y+G5k+33uN/oHuffsA3bdih/bWXUz3\nvt5E963D23plO9E1Mt+he/9fCSxuZYOD/m3xex/lGN/Vfh8PAn8OPHGm24OZnLAtAtui6WiL3jfK\nMb1vjLrPbuU/Ysu25A29Ol8CXjvO/i4bZf2r+q8/3Xvz+3Tv1Tf21t2V7n26ke4buf8O/MzA7+um\nts1vAS9u8dvoDZbJKANuDhzjb7d9P0Q3qO5uM90ezOSEbRHYFm3XtohJtC0D9Re2fd1Pd81wHfCW\ngTq2RXNswrYIbIu2d1s0Ydsywe/sfTx+QG8/o/WmkV++NLSWOf8W3Rtx80T1p2B/fwlcVN3jtbd1\nW/8deG5V/YdtP7LtI93jON9YVUdPWHn09d9E19C+bEoPTJplbIu2r/at2f+uql8acv2D6S7KtuZu\nB2mHY1u0fdkWSZNjW7R9+Rnt8UwuaShJfoPu9sefpesX+5OqOmpmj2rrpBsw72q6RuFrE9XfUc3F\nhksaYVu04/ADneYy26Idh22R5jLboh3HXPyMNm/GXNKUeyvdraS30PW/HW1QuVkr3SMg7wC+PJcb\nLWkesC2SNBvYFkmaDWyLNGO8c0mSJEmSJElD884lSZIkSZIkDc3kkiRJkiRJkoa2YKYPYKrtscce\ntWTJkpk+DEnb6Kqrrvp+VS2c6eMYlm2RNDfYFkmaDWyLJM0G47VFcy65tGTJEtauXTvThyFpGyW5\nfaaPYVvYFklzg22RpNnAtkjSbDBeW2S3OEmSJEmSJA3N5JIkSZIkzXFJ9k5yaZIbklyf5B0t/r4k\nG5Jc06YjeuuckmRdkpuSHNaLL2+xdUlOnonzkTS7zLlucZIkSZKkx9kMvLuqvpnkacBVSda0sjOq\n6n/2KyfZFzgGeD7wTOD/T/LcVvwx4FXAeuDKJKuq6oZpOQtJs5LJJUmSJEma46rqTuDONv+DJDcC\ni8ZZ5Ujggqp6BPhOknXAga1sXVXdCpDkglbX5JI0j9ktTpIkSZLmkSRLgBcDV7TQSUmuTbIyya4t\ntgi4o7fa+hYbKz64jxOSrE2yduPGjVN8BpJmG5NLkiRJkjRPJHkq8FngnVX1IHAm8AvAfnR3Nv3J\nVOynqs6qqmVVtWzhwlGfXC5pDrFbnCRJkiTNA0meQJdYOr+qPgdQVXf3yj8BfLEtbgD27q2+uMUY\nJy5pnvLOJUmSJEma45IEOBu4sao+3Ivv1av2G8C32vwq4JgkT0yyD7AU+AZwJbA0yT5JdqYb9HvV\ndJyDpNnLO5ckSZIkae57KfBG4Lok17TY7wPHJtkPKOA24K0AVXV9kovoBureDJxYVY8CJDkJuBjY\nCVhZVddP54lImn1MLkmSJEnSHFdVXwcyStHqcdY5HTh9lPjq8daTNP/YLU6SJEmSJElD884l7XCW\nnPyl7bLd2z746u2yXUkza3u1GWC7IWl28NpI0tawzdD24J1LkiRJkiRJGprJJUlzQpLfTXJ9km8l\n+XSSJ7WnmFyRZF2SC9sTTWhPPbmwxa9IsqS3nVNa/KYkh/Xiy1tsXZKTp/8MJUmSJGl2MrkkaYeX\nZBHwX4BlVfUCuieXHAN8CDijqp4D3Acc31Y5Hrivxc9o9Uiyb1vv+cBy4ONJdkqyE/Ax4HBgX7qn\nquw7XecnSZIkSbOZySVJc8UC4MlJFgA/C9wJvAL4TCs/FziqzR/ZlmnlhyRJi19QVY9U1XeAdcCB\nbVpXVbdW1Y+BC1pdSZIkSZr3TC5J2uFV1QbgfwLfpUsqPQBcBdxfVZtbtfXAoja/CLijrbu51d+9\nHx9YZ6y4JEmSJM17Jpck7fCS7Ep3J9E+wDOBp9B1a5vu4zghydokazdu3Djdu5ckSZKkGWFySdJc\n8ErgO1W1sar+Ffgc8FJgl9ZNDmAxsKHNbwD2BmjlzwDu7ccH1hkrvoWqOquqllXVsoULF07VuUna\nQSR5XpJretODSd6ZZLcka5Lc3H7u2uonyUfbgwKuTbJ/b1srWv2bk6zoxQ9Icl1b56OtS68kSdKM\nmjC5lGTvJJcmuaE9iekdLb7dL5TG2ockDfgucFCSn23txyHADcClwOtanRXAF9r8qrZMK/9qVVWL\nH9OeJrcPsBT4BnAlsLQ9fW5nukG/V03DeUnagVTVTVW1X1XtBxwAPAx8HjgZuKSqlgKXtGXoHhKw\ntE0nAGdCd/0DnAq8hG7Mt1N710BnAm/prTftd2lKkiQNmsydS5uBd1fVvsBBwIntKUnTcaE01j4k\n6aeq6gq6gbm/CVxH17adBbwHeFeSdXRjKp3dVjkb2L3F30VrW6rqeuAiusTUV4ATq+rRNi7TScDF\nwI3ARa2uJI3lEOCWqrqdLR8iMPhwgfOqcznd3ZZ7AYcBa6pqU1XdB6wBlreyp1fV5S0hfl5vW5Ik\nSTNmwUQVqupOugFyqaofJLmRbiDbI4GDW7VzgcvoPsj99EIJuDzJyIXSwbQLJYAkIxdKl9EulFp8\n5ELpy+PsQ5K2UFWn0iWw+26lS2YP1v0R8PoxtnM6cPoo8dXA6m0/UknzxDHAp9v8nu16CuAuYM82\nv7UPEVjU5gfjkiRJM2qrxlxKsgR4MXAF03OhNNY+JEmSZqXWffa1wF8NlrUv32o779+HC0iSpGk1\n6eRSkqcCnwXeWVUP9sum40JpvH14ESVJkmaRw4FvVtXdbfnudhc37ec9Lb61DxHY0OYH41vw4QKS\nJGm6TSq5lOQJdIml86vqcy08HRdKY+1jC15ESZKkWeRYHusSB1s+RGDw4QLHtYehHAQ80O7Yvhg4\nNMmubXzKQ4GLW9mDSQ5qDy84rrctSZKkGTOZp8WFbvDbG6vqw72i6bhQGmsfkiRJs06SpwCvAj7X\nC38QeFWSm4FXtmXoxnG7FVgHfAJ4O0Abn/I0uidVXgm8f2TMylbnk22dW+jGqJQkSZpREw7oDbwU\neCNwXZJrWuz36S6MLkpyPHA7cHQrWw0cQXfR8zDwZugulJKMXCjB4y+UzgGeTHeRNHKhNNY+JEmS\nZp2qeoju6ZT92L10T48brFvAiWNsZyWwcpT4WuAFU3KwkiRJU2QyT4v7OpAxirfrhdJYF2OSJEmS\nJEmaHbbqaXGSJEmSJElSn8klSZIkSZIkDc3kkiRJkiRJkoZmckmSJEmSJElDM7kkSZIkSZKkoZlc\nkiRJkiRJ0tBMLkmSJEmSJGloJpckSZIkSZI0NJNLkiRJkiRJGprJJUmSJEmSJA3N5JIkSZIkSZKG\nZnJJkiRJkiRJQzO5JEmSJEmSpKGZXJIkSZIkSdLQTC5JkiRJkiRpaCaXJEmSJEmSNDSTS5IkSZIk\nSRqaySVJO7wkz0tyTW96MMk7k+yWZE2Sm9vPXVv9JPloknVJrk2yf29bK1r9m5Os6MUPSHJdW+ej\nSTIT5ypJkiRJs43JJUk7vKq6qar2q6r9gAOAh4HPAycDl1TVUuCStgxwOLC0TScAZwIk2Q04FXgJ\ncCBw6khCqtV5S2+95dNwapIkSZI065lckjTXHALcUlW3A0cC57b4ucBRbf5I4LzqXA7skmQv4DBg\nTVVtqqr7gDXA8lb29Kq6vKoKOK+3LUmSJEma10wuSZprjgE+3eb3rKo72/xdwJ5tfhFwR2+d9S02\nXnz9KPEtJDkhydokazdu3Lit5yFJkiRJOwSTS5LmjCQ7A68F/mqwrN1xVNtz/1V1VlUtq6plCxcu\n3J67kiRJkqRZY8LkUpKVSe5J8q1e7MLewLm3JbmmxZck+Zde2Z/11hl1MNxhBtyVpDEcDnyzqu5u\ny3e3Lm20n/e0+AZg7956i1tsvPjiUeKSJEmSNO9N5s6lcxgYuLaqfqs3eO5ngc/1im8ZKauqt/Xi\nYw2Gu1UD7krSOI7lsS5xAKuAkSe+rQC+0Isf15LYBwEPtO5zFwOHJtm1JboPBS5uZQ8mOaglxo/r\nbUuSJEmS5rUJk0tV9TVg02hl7UPW0Wz5YW60euMNhru1A+5K0uMkeQrwKrZMdn8QeFWSm4FXtmWA\n1cCtwDrgE8DbAapqE3AacGWb3t9itDqfbOvcAnx5e56PJEmSJO0oFmzj+r8C3F1VN/di+yS5GngQ\neG9V/T3jD4a7tQPu3okkDaiqh4DdB2L30j09brBuASeOsZ2VwMpR4muBF0zJwUqas5LsQpeIfgHd\nOG//EbgJuBBYAtwGHF1V97Uv6T4CHAE8DLypqr7ZtrMCeG/b7Aeq6twWP4DurvIn0yXK39HaNEmS\npBmzrQN6D3ZBuRN4VlW9GHgX8JdJnj7ZjQ074K5PaJIkSbPER4CvVNUvAi8CbmQrhwBIshtwKvAS\n4EDg1JExKRl7mAFJGleSvZNcmuSGJNcneUeLb/UYuElWtPo3t2S4pHlu6ORSkgXAv6f7Jg6Aqnqk\n3SlAVV1F13XkuYw/GO7WDrj7OD6hSZIkzbQkzwBeDpwNUFU/rqr72fohAA4D1lTVpqq6D1gDLJ9g\nmAFJmshm4N1VtS9wEHBikn2Z2gS4pHlqW+5ceiXw7ar6aXe3JAuT7NTmf56uIbp1gsFwt3bAXUmS\npNloH2Aj8OdJrk7yyTYe3NYOATBefKxhBiRpXFV150jX26r6Ad2dlYuYogT4NJ6KpFlowuRSkk8D\n/wg8L8n6JMe3omN4/EDeLweuTXIN8BngbZMYDHerBtyVJEmapRYA+wNntiECHuKxOwCA4YcA2BoO\nFyBpIkmWAC8GrmDqEuCD+7AtkuaRCQf0rqpjx4i/aZTYZ4HPjlF/1MFwhxlwV5IkaRZaD6yvqiva\n8mfokkt3J9mrqu6c5BAAG4CDB+KXMf4wAz9VVWcBZwEsW7bMwb4lbSHJU+k+s72zqh7sOpZ0qqqS\nTEm7YVskzS/bOqC3JEmSgKq6C7gjyfNa6BDgBrZ+CICLgUOT7NrGMTkUuHiCYQYkaUJJnkCXWDq/\nqj7Xwls7Bu6kx8aVNH+YXJIkSZo6/xk4P8m1wH7A/8dWDgHQhhQ4DbiyTe+fxDADkjSulpQ+G7ix\nqj7cK5qSBPi0nISkWWvCbnGSJEmanKq6Blg2StFWDQFQVSuBlaPERx1mQJIm4aXAG4Hr2hi5AL9P\nl/C+qI2teztwdCtbDRxBl8x+GHgzdAnwJCMJcNgyAS5pnjK5JEmSJElzXFV9HcgYxVOSAJc0f9kt\nTpIkSZIkSUMzuSRJkiRJkqShmVySJEmSJEnS0EwuSZIkSZIkaWgmlyRJkiRJkjQ0k0uSJEmSJEka\nmsklSZIkSZIkDc3kkiRJkiRJkoZmckmSJEmSJElDM7kkSZIkSZKkoZlckiRJkiRJ0tBMLkmSJEmS\nJGloJpckSZIkSZI0NJNLkuaEJLsk+UySbye5MckvJdktyZokN7efu7a6SfLRJOuSXJtk/952VrT6\nNydZ0YsfkOS6ts5Hk2QmzlOSJEmSZhuTS5Lmio8AX6mqXwReBNwInAxcUlVLgUvaMsDhwNI2nQCc\nCZBkN+BU4CXAgcCpIwmpVuctvfWWT8M5SZIkSdKsZ3JJ0g4vyTOAlwNnA1TVj6vqfuBI4NxW7Vzg\nqDZ/JHBedS4HdkmyF3AYsKaqNlXVfcAaYHkre3pVXV5VBZzX25YkSZIkzWsmlyTNBfsAG4E/T3J1\nkk8meQqwZ1Xd2ercBezZ5hcBd/TWX99i48XXjxKXJEmSpHnP5JKkuWABsD9wZlW9GHiIx7rAAdDu\nOKrteRBJTkiyNsnajRs3bs9dSZIkSdKsMWFyKcnKJPck+VYv9r4kG5Jc06YjemWntAFvb0pyWC++\nvMXWJTm5F98nyRUtfmGSnVv8iW15XStfMlUnLWnOWQ+sr6or2vJn6JJNd7cubbSf97TyDcDevfUX\nt9h48cWjxLdQVWdV1bKqWrZw4cJtPilJkiRJ2hFM5s6lcxh94Nozqmq/Nq0GSLIvcAzw/LbOx5Ps\nlGQn4GN0g+juCxzb6gJ8qBdvTO0AACAASURBVG3rOcB9wPEtfjxwX4uf0epJ0uNU1V3AHUme10KH\nADcAq4CRJ76tAL7Q5lcBx7Wnxh0EPNC6z10MHJpk1zaQ96HAxa3swSQHtafEHdfbliRJkiTNawsm\nqlBVX9uKu4aOBC6oqkeA7yRZR/fEJYB1VXUrQJILgCOT3Ai8AvjtVudc4H10T2U6ss1DdxfCnyZJ\n69oiSYP+M3B+u/vxVuDNdAn0i5IcD9wOHN3qrgaOANYBD7e6VNWmJKcBV7Z676+qTW3+7XTJ9icD\nX26TJEmSJM17EyaXxnFSkuOAtcC725OVFgGX9+r0B70dHCT3JcDuwP1VtXmU+j8dWLeqNid5oNX/\n/jYcs6Q5qqquAZaNUnTIKHULOHGM7awEVo4SXwu8YBsPU5IkSZLmnGEH9D4T+AVgP+BO4E+m7IiG\n4CC6kiRJkiRJM2Oo5FJV3V1Vj1bVT4BP8FjXt60dJPdeYJckCwbiW2yrlT+j1R/teBxEV5IkSZIk\naQYMlVwaefpS8xvAyJPkVgHHtCe97QMsBb5BN37J0vZkuJ3pBv1e1bqmXAq8rq0/OODuyEC8rwO+\n6nhLkiRJkiRJs8uEYy4l+TRwMLBHkvXAqcDBSfYDCrgNeCtAVV2f5CK6pzRtBk6sqkfbdk6iexLT\nTsDKqrq+7eI9wAVJPgBcDZzd4mcDn2qDgm+iS0hJkiRJkiRpFpnM0+KOHSV89iixkfqnA6ePEl9N\n94SmwfitPNatrh//EfD6iY5PkiRptkhyG/AD4FFgc1UtS7IbcCGwhO5LuaOr6r4kAT5C9/TKh4E3\nVdU323ZWAO9tm/1AVZ3b4gfw2JMrVwPv8M5uSZI004Yd0FuSJEmj+7Wq2q+qRp5geTJwSVUtBS5p\nywCH0w0hsBQ4ge6BKbRk1Kl0T9Y9EDg1ya5tnTOBt/TWW779T0eSJGl8JpckSZK2ryOBc9v8ucBR\nvfh51bmc7iEnewGHAWuqalNV3QesAZa3sqdX1eXtbqXzetuSJEmaMSaXJEmSpk4Bf5vkqiQntNie\nVXVnm78L2LPNLwLu6K27vsXGi68fJb6FJCckWZtk7caNG7f1fCRJkiY04ZhLkiRJmrSXVdWGJD8H\nrEny7X5hVVWS7TpGUlWdBZwFsGzZMsdjkiRJ2513LkmSJE2RqtrQft4DfJ5uzKS7W5c22s97WvUN\nwN691Re32HjxxaPEJUmSZpTJJUmSpCmQ5ClJnjYyDxwKfAtYBaxo1VYAX2jzq4Dj0jkIeKB1n7sY\nODTJrm0g70OBi1vZg0kOak+aO663LUmSpBljtzhJkqSpsSfw+S7vwwLgL6vqK0muBC5KcjxwO3B0\nq78aOAJYBzwMvBmgqjYlOQ24stV7f1VtavNvB84Bngx8uU2SJEkzyuSSJEnSFKiqW4EXjRK/Fzhk\nlHgBJ46xrZXAylHia4EXbPPBSpIkTSG7xUmSJEmSJGloJpckSZIkSZI0NJNLkiRJkiRJGprJJUmS\nJEmSJA3N5JIkSZIkSZKGZnJJkiRJkiRJQzO5JEmSJEmSpKGZXJIkSZIkSdLQTC5JkiRJkiRpaCaX\nJEmSJGmOS7IyyT1JvtWLvS/JhiTXtOmIXtkpSdYluSnJYb348hZbl+Tk6T4PSbOTySVJc0KS25Jc\n1y6M1rbYbknWJLm5/dy1xZPko+2i6Nok+/e2s6LVvznJil78gLb9dW3dTP9ZSpIkDe0cYPko8TOq\nar82rQZIsi9wDPD8ts7Hk+yUZCfgY8DhwL7Asa2upHnO5JKkueTX2oXRsrZ8MnBJVS0FLmnL0F0Q\nLW3TCcCZ0CWjgFOBlwAHAqeOJKRanbf01hvt4kySJGlWqqqvAZsmWf1I4IKqeqSqvgOso7s2OhBY\nV1W3VtWPgQtaXUnznMklSXPZkcC5bf5c4Khe/LzqXA7skmQv4DBgTVVtqqr7gDXA8lb29Kq6vKoK\nOK+3LUmSpB3ZSe1O7pW9L9UWAXf06qxvsbHikuY5k0uS5ooC/jbJVUlOaLE9q+rONn8XsGeb39oL\npkVtfjAuSZK0IzsT+AVgP+BO4E+masNJTkiyNsnajRs3TtVmJc1SEyaXxhj47X8k+XbLcH8+yS4t\nviTJv/QGhPuz3jqjjlcyzJgokjSKl1XV/nRd3k5M8vJ+YbvjqLbnAXgRJUmSdiRVdXdVPVpVPwE+\nQdftDWADsHev6uIWGys+2rbPqqplVbVs4cKFU3/wkmaVydy5dA6PH1tkDfCCqnoh8M/AKb2yW3oD\nwr2tFx9rvJKtGhNFkkZTVRvaz3uAz9NdHN3durTRft7Tqm/tBdOGNj8YHzwGL6IkSdIOY+Q6qfkN\nYOSGglXAMUmemGQfus9k3wCuBJYm2SfJznSDfq+azmOWNDtNmFwabeC3qvrbqtrcFi9nyw9djzPB\neCVbOyaKJG0hyVOSPG1kHjiU7uJoFTDyxLcVwBfa/CrguHaH5EHAA6373MXAoUl2bXdRHgpc3Moe\nTHJQu+vyuN62JEmSZr0knwb+EXhekvVJjgf+uPUuuRb4NeB3AarqeuAi4AbgK8CJ7Q6nzcBJdNdM\nNwIXtbqS5rkFU7CN/whc2FveJ8nVwIPAe6vq7xl/vJKtHRPlTiRpS3sCn2+9bRcAf1lVX0lyJXBR\nu3i6HTi61V8NHEH35JOHgTcDVNWmJKfRfSsH8P6qGkmuv53uTs4nA19ukyRJ0g6hqo4dJXz2OPVP\nB04fJb6a7lpKkn5qm5JLSf4bsBk4v4XuBJ5VVfcmOQD46yTPn+z2qqqSbPWYKG3w3hMAnvWsZ23t\n6pJ2cFV1K/CiUeL3AoeMEi/gxDG2tRJYOUp8LfCCbT5YSZIkSZpjhn5aXJI3Aa8B3tA+qFFVj7QP\nc1TVVcAtwHMZf7ySrR0T5XEc50SSJEmSJGlmDJVcSrIc+D3gtVX1cC++MMlObf7n6QZ+u3WC8Uq2\ndkwUSZIkSZIkzRITdotrA78dDOyRZD1wKt3T4Z4IrGljnFzengz3cuD9Sf4V+AnwtkmMV/JBtmJM\nFEmSJEmSJM0eEyaXtmbgt6r6LPDZMcpGHa9kmDFRJEmSJEmSNDsMPeaSJEmSJEmSZHJJkiRJkiRJ\nQzO5JEmSJEmSpKGZXJIkSZpCSXZKcnWSL7blfZJckWRdkguT7NziT2zL61r5kt42Tmnxm5Ic1osv\nb7F1SU6e7nOTJEkajcklSZKkqfUO4Mbe8oeAM6rqOcB9wPEtfjxwX4uf0eqRZF/gGOD5wHLg4y1h\ntRPwMeBwYF/g2FZXkiRpRplckiRJmiJJFgOvBj7ZlgO8AvhMq3IucFSbP7It08oPafWPBC6oqkeq\n6jvAOuDANq2rqlur6sfABa2uJEnSjDK5JEmSNHX+F/B7wE/a8u7A/VW1uS2vBxa1+UXAHQCt/IFW\n/6fxgXXGikuSJM0ok0uSJElTIMlrgHuq6qoZPo4TkqxNsnbjxo0zeSiSJGmeMLkkSZI0NV4KvDbJ\nbXRd1l4BfATYJcmCVmcxsKHNbwD2BmjlzwDu7ccH1hkrvoWqOquqllXVsoULF07NmUmSJI3D5JIk\nSdIUqKpTqmpxVS2hG5D7q1X1BuBS4HWt2grgC21+VVumlX+1qqrFj2lPk9sHWAp8A7gSWNqePrdz\n28eqaTg1SZKkcS2YuIokSZK2wXuAC5J8ALgaOLvFzwY+lWQdsIkuWURVXZ/kIuAGYDNwYlU9CpDk\nJOBiYCdgZVVdP61nIkmSNAqTS5IkSVOsqi4DLmvzt9I96W2wzo+A14+x/unA6aPEVwOrp/BQJUmS\ntpnd4iRJkiRJkjQ0k0uSJEmSJEkamsklSZIkSZIkDc3kkiRJkiRJkoZmckmSJEmSJElDM7kkSZIk\nSZKkoZlckiRJkiRJ0tBMLkmaE5LslOTqJF9sy/skuSLJuiQXJtm5xZ/Ylte18iW9bZzS4jclOawX\nX95i65KcPN3nJkmSJEmzmcklSXPFO4Abe8sfAs6oqucA9wHHt/jxwH0tfkarR5J9gWOA5wPLgY+3\nhNVOwMeAw4F9gWNbXUmSJEkSJpckzQFJFgOvBj7ZlgO8AvhMq3IucFSbP7It08oPafWPBC6oqkeq\n6jvAOuDANq2rqlur6sfABa2uJEmSJIlJJpeSrExyT5Jv9WK7JVmT5Ob2c9cWT5KPtu4j1ybZv7fO\nilb/5iQrevEDklzX1vlo+6A35j4kacD/An4P+Elb3h24v6o2t+X1wKI2vwi4A6CVP9Dq/zQ+sM5Y\n8cdJckKStUnWbty4cVvPSZIkSZJ2CJO9c+kcum4ifScDl1TVUuCStgxd15GlbToBOBO6RBFwKvAS\nujsBTu0li84E3tJbb/kE+5AkAJK8Brinqq6a6WOpqrOqallVLVu4cOFMH44kSZIkTYtJJZeq6mvA\npoFwv2vJYJeT86pzObBLkr2Aw4A1VbWpqu4D1gDLW9nTq+ryqirgPEbvvtLfhySNeCnw2iS30XVZ\newXwEbq2Z0GrsxjY0OY3AHsDtPJnAPf24wPrjBWXJEmSJLFtYy7tWVV3tvm7gD3b/NZ2LVnU5gfj\n4+1jC3ZFkeavqjqlqhZX1RK6Abm/WlVvAC4FXteqrQC+0OZXtWVa+VdbYnsVcEx7mtw+dHdRfgO4\nEljanj63c9vHqmk4NUmSJEnaIUzJgN7tg1lNxbaG2YddUSSN4j3Au5KsoxtT6ewWPxvYvcXfRetu\nW1XXAxcBNwBfAU6sqkfbuEwnARfTPY3uolZXkiRJkgQsmLjKmO5OsldV3dm6tt3T4uN1LTl4IH5Z\niy8epf54+5Ckx6mqy+jaFarqVrrx3Qbr/Ah4/Rjrnw6cPkp8NbB6Cg9VkiRJkuaMbblzqd+1ZLDL\nyXHtqXEHAQ+0rm0XA4cm2bUN5H0ocHErezDJQe0pcccxeveV/j4kSZIkSZI0C0zqzqUkn6a762iP\nJOvpnvr2QeCiJMcDtwNHt+qrgSOAdcDDwJsBqmpTktPoxi8BeH9VjQwS/na6J9I9GfhymxhnH5Ik\nSZIkSZoFJpVcqqpjxyg6ZJS6BZw4xnZWAitHia8FXjBK/N7R9iFJkiRJkqTZYUoG9JYkSZIkSdL8\nZHJJkiRJkiRJQzO5JEmSJEmSpKGZXJIkSZIkSdLQTC5JkiRJkiRpaCaXJEmSJEmSNDSTS5IkSZIk\nSRqaySVJkiRJkiQNzeSSJEnSFEjypCTfSPJPSa5P8octvk+SK5KsS3Jhkp1b/IlteV0rX9Lb1ikt\nflOSw3rx5S22LsnJ032OknZcSVYmuSfJt3qx3ZKsSXJz+7lriyfJR1tbc22S/XvrrGj1b06yYibO\nRdLsY3JJkiRpajwCvKKqXgTsByxPchDwIeCMqnoOcB9wfKt/PHBfi5/R6pFkX+AY4PnAcuDjSXZK\nshPwMeBwYF/g2FZXkibjHLo2pe9k4JKqWgpc0paha2eWtukE4EzoklHAqcBLgAOBU0cSUpLmN5NL\nkiRJU6A6P2yLT2hTAa8APtPi5wJHtfkj2zKt/JAkafELquqRqvoOsI7uQ9yBwLqqurWqfgxc0OpK\n0oSq6mvApoFwvx0abJ/Oa+3a5cAuSfYCDgPWVNWmqroPWMPjE1aS5iGTS5IkSVOk3WF0DXAP3Yeu\nW4D7q2pzq7IeWNTmFwF3ALTyB4Dd+/GBdcaKDx7DCUnWJlm7cePGqTo1SXPTnlV1Z5u/C9izzW9T\nOyRp/jG5JEmSNEWq6tGq2g9YTHen0S/OwDGcVVXLqmrZwoULp3v3knZQVVV0d1tOCRPd0vxickmS\nJGmKVdX9wKXAL9F1J1nQihYDG9r8BmBvgFb+DODefnxgnbHikjSsu1t3N9rPe1p8m9shE93S/GJy\nSZIkaQokWZhklzb/ZOBVwI10SabXtWorgC+0+VVtmVb+1XbnwCrgmPY0uX3oBtT9BnAlsLQ9fW5n\nukG/V23/M5M0h/XbocH26bj21LiDgAda97mLgUOT7NoG8j60xSTNcwsmriJJkqRJ2As4tz3V7WeA\ni6rqi0luAC5I8gHgauDsVv9s4FNJ1tENsnsMQFVdn+Qi4AZgM3BiVT0KkOQkug9yOwErq+r66Ts9\nSTuyJJ8GDgb2SLKe7qlvHwQuSnI8cDtwdKu+GjiC7oECDwNvBqiqTUlOo0t2A7y/qgYHCZc0D5lc\nkiRJmgJVdS3w4lHit9KNvzQY/xHw+jG2dTpw+ijx1XQf+iRpq1TVsWMUHTJK3QJOHGM7K4GVU3ho\nkuYAu8VJkiRJkiRpaCaXJEmSJEmSNDSTS5J2eEmelOQbSf4pyfVJ/rDF90lyRZJ1SS5sA+DSBsm9\nsMWvSLKkt61TWvymJIf14stbbF2Sk6f7HCVJkiRptjK5JGkueAR4RVW9CNgPWN6ebPIh4Iyqeg5w\nH3B8q388cF+Ln9HqkWRfugF1nw8sBz6eZKc2OO/HgMOBfYFjW11JkiRJmvdMLkna4VXnh23xCW0q\n4BXAZ1r8XOCoNn9kW6aVH5IkLX5BVT1SVd+he0LKgW1aV1W3VtWPgQtaXUmSJEma94ZOLiV5XpJr\netODSd6Z5H1JNvTiR/TW2aruJmN1aZGkQe0Oo2uAe4A1wC3A/VW1uVVZDyxq84uAOwBa+QPA7v34\nwDpjxSVJkiRp3hs6uVRVN1XVflW1H3AA8DDw+VZ8xkhZe2TusN1NxurSIklbqKpHW3u0mO5Oo1+c\n7mNIckKStUnWbty4cbp3L0mSJEkzYqq6xR0C3FJVt49TZ6u6m7QuKmN1aZGkUVXV/cClwC8BuyRZ\n0IoWAxva/AZgb4BW/gzg3n58YJ2x4oP7PquqllXVsoULF07ZOUmSJEnSbDZVyaVjgE/3lk9Kcm2S\nlUl2bbGt7W6yO2N3admCdwtI81uShUl2afNPBl4F3EiXZHpdq7YC+EKbX9WWaeVfrapq8WPa0+T2\nAZYC3wCuBJa2rro707V5q7b/mUmSJEnS7LfNyaX2Qeu1wF+10JnAL9A9selO4E+2dR8T8W4Bad7b\nC7g0ybV0iaA1VfVF4D3Au5Kso0tYn93qnw3s3uLvAk4GqKrrgYuAG4CvACe27nabgZOAi+mSVhe1\nupIkSZI07y2YuMqEDge+WVV3A4z8BEjyCeCLbXG8biWjxe+ldWlpH+xG7YYiSVV1LfDiUeK30nW9\nHYz/CHj9GNs6HTh9lPhqYPU2H6wkSZIkzTFT0S3uWHpd4pLs1Sv7DeBbbX6rupu0LipjdWmRJEmS\nJEnSLLBNdy4leQrd2CZv7YX/OMl+QAG3jZRV1fVJRrqbbKZ1N2nbGelushOwstfd5D3ABUk+AFzN\nY11aJEmSJEmSNAtsU3Kpqh6iG8ekH3vjOPW3qrvJWF1aJEmSJEmSNDtM1dPiJEmSJEmSNA+ZXJIk\nSZIkSdLQTC5JkiRJkiRpaCaXJEmSJEmSNDSTS5IkSZIkSRqaySVJkiRJkiQNzeSSJEmSJEmShmZy\nSZIkSZIkSUMzuSRJkiRJkqShmVySJEmSJEnS0EwuSZIkSZIkaWgmlyRJkiRJkjQ0k0uSJElTIMne\nSS5NckOS65O8o8V3S7Imyc3t564tniQfTbIuybVJ9u9ta0Wrf3OSFb34AUmua+t8NEmm/0wlSZK2\nZHJJkiRpamwG3l1V+wIHAScm2Rc4GbikqpYCl7RlgMOBpW06ATgTumQUcCrwEuBA4NSRhFSr85be\nesun4bwkSZLGZXJJkiRpClTVnVX1zTb/A+BGYBFwJHBuq3YucFSbPxI4rzqXA7sk2Qs4DFhTVZuq\n6j5gDbC8lT29qi6vqgLO621LkiRpxphckiRJmmJJlgAvBq4A9qyqO1vRXcCebX4RcEdvtfUtNl58\n/ShxSZKkGWVySZIkaQoleSrwWeCdVfVgv6zdcVTbef8nJFmbZO3GjRu3564kSZIAk0uSJElTJskT\n6BJL51fV51r47taljfbznhbfAOzdW31xi40XXzxKfAtVdVZVLauqZQsXLtz2k5IkSZqAySVJkqQp\n0J7cdjZwY1V9uFe0Chh54tsK4Au9+HHtqXEHAQ+07nMXA4cm2bUN5H0ocHErezDJQW1fx/W2JUmS\nNGMWzPQBSJIkzREvBd4IXJfkmhb7feCDwEVJjv+/7d1/rN31fd/x56s4kN/DEMdjMdRko9MArSTx\ngKlZlYQECFUHbaOIagpumtXLcKR2a6W6S6ew/JBIpv4Ia5fITT2MlBRoUharcUJdlKyNVCgmIYBD\nmY3jCLsEGCYBQpOK5r0/vh+H48u99r3n9z33+ZCOzjmf7+f7/Xze58f7nu/nfr+fL/BN4O1t2U7g\nMmAf8AzwToCqOpzkA8Cdrd77q+pwe3w1cD3wIuDz7SZJkjRRDi5JWvaSnE531aS1dHOZbK2qj7bL\ned8ErAcOAG+vqifaf/w/SrdT9wzwC0eu8JRkI/CbbdMfrKrtrfx1PLdDtxP45TZ3iiQBUFVfBrLA\n4ovmqV/A5gW2tQ3YNk/5buDcAbopSZI0dAOfFpfkQJJ7k9ydZHcrOyXJriR72/3qVp4k1yXZl+Se\nJK/t2c7GVn9v27k7Uv66tv19bd2FfrRJWrmeBX61qs4GLgQ2Jzkb2ALcVlVnAbe15wBvBc5qt03A\nx6DLXcD7gAuA84H3Hclfrc4v9ax36RjikiRJkqSpN6w5l95YVedV1Yb23B06SWNTVQ8fOfKoqp4C\n7qe7PPflwPZWbTtwRXt8OXBDdW4HTm6T7F4C7Kqqw1X1BLALuLQte3lV3d6ONLihZ1uSJEmStKKN\nakJvd+gkTUSS9cBrgDuAtW0CXIBv0Z02B93A00M9qx1sZccqPzhPuSRJkiSteMMYXCrgz5LclWRT\nK3OHTtLYJXkp3SXAf6Wqnuxd1gaoRzpHUpJNSXYn2f3YY4+NsilJkiRJmhrDGFx6fVW9lu6Ut81J\nfrJ3oTt0ksYhyQvoBpY+WVV/0oofaUdA0u4fbeWHgNN7Vl/Xyo5Vvm6e8qNU1daq2lBVG9asWTN4\nUJIkSZK0DAw8uFRVh9r9o8AtdHMmuUMnaWzaRP9/CNxfVb/ds2gHcOQCARuBz/aUX9UuMnAh8J12\ntOWtwMVJVrd53y4Gbm3LnkxyYWvrqp5tSZIkSdKKNtDgUpKXJHnZkcd0O2L34Q6dpPH6CeAdwJva\nlSvvTnIZcC3wliR7gTe35wA7gf3APuAPgKsBquow8AHgznZ7fyuj1flEW+dB4PPjCEySJEmSpt2q\nAddfC9zSjfuwCvhUVX0hyZ3AzUneBXwTeHurvxO4jG7n7BngndDt0CU5skMHz9+hux54Ed3OnDt0\nko5SVV8GssDii+apX8DmBba1Ddg2T/lu4NwBuilJkiRJM2mgwaWq2g/8+Dzlj+MOnSRJkiRJ0swb\nxoTekiRJkqRlKsmBJPe2qQV2t7JTkuxKsrfdr27lSXJdkn1J7kny2sn2XtI0cHBJkiRJkvTGqjqv\nqja051uA26rqLOC29hy6q4Sf1W6bgI+NvaeSpo6DS5IkSZKkuS4HtrfH24ErespvqM7twMlHrhQu\naeVycEmSJEmSVrYC/izJXUk2tbK17erdAN+iu5gTwKuAh3rWPdjKJK1gg14tTpIkSdIirN/yuUl3\nQVrI66vqUJJXAruS/E3vwqqqJLWUDbZBqk0AZ5xxxvB6KmkqeeSSJEmSJK1gVXWo3T8K3AKcDzxy\n5HS3dv9oq34IOL1n9XWtbO42t1bVhqrasGbNmlF2X9IUcHBJkiRJklaoJC9J8rIjj4GLgfuAHcDG\nVm0j8Nn2eAdwVbtq3IXAd3pOn5O0QnlanCRJkiStXGuBW5JAt3/4qar6QpI7gZuTvAv4JvD2Vn8n\ncBmwD3gGeOf4uyxp2ji4JEmSJEkrVFXtB358nvLHgYvmKS9g8xi6JmkZ8bQ4SZIkSZIk9c3BJUmS\nJEmSJPXNwSVJkiRJkiT1zcElSZIkSZIk9c3BJUmSJEmSJPXNwSVJkiRJkiT1zcElSZIkSZIk9c3B\nJUmSJEmSJPXNwSVJkiRJkiT1zcElSZKkIUiyLcmjSe7rKTslya4ke9v96laeJNcl2ZfkniSv7Vln\nY6u/N8nGnvLXJbm3rXNdkow3QkmSpPk5uCRJkjQc1wOXzinbAtxWVWcBt7XnAG8Fzmq3TcDHoBuM\nAt4HXACcD7zvyIBUq/NLPevNbUuSJGkiHFySJEkagqr6C+DwnOLLge3t8Xbgip7yG6pzO3ByktOA\nS4BdVXW4qp4AdgGXtmUvr6rbq6qAG3q2JUmSNFEOLkla9jwVRdIUW1tVD7fH3wLWtsevAh7qqXew\nlR2r/OA85c+TZFOS3Ul2P/bYY4NHIEmSdBx9Dy4lOT3JF5N8PcmeJL/cyq9JcijJ3e12Wc86v9F2\nzh5IcklP+aWtbF+SLT3lZya5o5XflOTEfvsraaZdj6eiSJpy7YijGkM7W6tqQ1VtWLNmzaibkyRJ\nGujIpWeBX62qs4ELgc1Jzm7Lfqeqzmu3nQBt2ZXAOXQ7Zv8zyQlJTgB+n26H72zg53u28+G2rX8G\nPAG8a4D+SppRnooiaYo90vII7f7RVn4IOL2n3rpWdqzydfOUS5IkTVzfg0tV9XBVfaU9fgq4nwUO\nz24uB26squ9X1TeAfXRHB5wP7Kuq/VX198CNwOXttJM3AZ9u6/fuHErS8Yz9VBRJmscO4MhpthuB\nz/aUX9VO1b0Q+E7LWbcCFydZ3Y6evBi4tS17MsmF7TfSVT3bkiRJmqihzLmUZD3wGuCOVvSeNpfJ\ntp7TSpa6Q3cq8O2qenZOuSQtybhORXGeE2llS/JHwF8B/zzJwSTvAq4F3pJkL/Dm9hxgJ7Cf7p9t\nfwBcDVBVh4EPAHe22/tbGa3OJ9o6DwKfH0dckiRJx7Nq0A0keSnwGeBXqurJJB+j+1FU7f63gF8c\ntJ3j9GET3dwpnHHGGaNsStLy8UiS06rq4SWcivKGOeVfYgmnolTVVmArwIYNG0Y+mCVpulTVzy+w\n6KJ56haweYHtbAO2IZmCCQAADHZJREFUzVO+Gzh3kD5KkiSNwkBHLiV5Ad3A0ier6k8AquqRqvqH\nqvoB3X/izm/Vlzq3wON0c6GsmlP+PE5cKWkenooiSZIkSWMwyNXiAvwhcH9V/XZP+Wk91X4GOHJp\n8B3AlUlOSnIm3RWX/prukO+z2pXhTqSb9HtH+4/eF4G3tfV7dw4l6Yc8FUWSJEmSJmeQ0+J+AngH\ncG+Su1vZf6G72tt5dKfFHQD+A0BV7UlyM/B1uivNba6qfwBI8h66owZOALZV1Z62vV8HbkzyQeCr\ndINZknQUT0WRJEmSpMnpe3Cpqr4MZJ5FO4+xzoeAD81TvnO+9apqP8+dVidJkiRJkqQpM5SrxUmS\nJEmSJGllGvhqcZIkSZIkaWVbv+VzI9nugWt/aiTb1XB55JIkSZIkSZL65uCSJEmSJEmS+ubgkiRJ\nkiRJkvrm4JIkSZIkSZL65uCSJEmSJEmS+ubgkiRJkiRJkvq2atIdkCRJkiRJR1u/5XOT7oK0aA4u\naWRMhpJm3ajy3IFrf2ok25UkSZJGwdPiJEmSJEmS1DcHlyRJkiRJktQ3B5ckSZIkSZLUNweXJEmS\nJEmS1DcHlyRJkiRJktQ3rxYnNV71SZIkSZKkpfPIJUmSJEmSJPXNwSVJkiRJkiT1zdPiJEmSJEnS\nVHL6kuXBI5ckSZIkSZLUN49ckiRNhVH9V0qSJEnSaDm4JEmSJOl5PBVFkrRYUz+4lORS4KPACcAn\nquraCXdJ0gplPpI0DcxFkqaBueg5Hn0tTfngUpITgN8H3gIcBO5MsqOqvj7ZnklaacxHkqaBuUjS\nNDAXaRZ4dOZwTfXgEnA+sK+q9gMkuRG4HDBpadkY5X8yVmrimhDzkcbGHzs6BnPRGHgUgnRc5iJJ\nR5n2waVXAQ/1PD8IXDChvswsf0AtX+6AjpX5qDFnSBNlLtKy5++XmTCyXOTvDC13y+0zPKzcOe2D\nS4uSZBOwqT19OskDC1R9BfD/xtMr256S9m27D/nw5Nru8aND2MZYLSEXHcukv6/DMgtxzEIM0BPH\ngN/tSZvU+7FSc9GxzMp3A4xlWvUVyxTnuGG8NyspF83SZxmMZ9rNWjywxJiWmDsXzEXTPrh0CDi9\n5/m6VnaUqtoKbD3expLsrqoNw+ve4q3Utifdvm2vrLZH7Lj5aLG56Fhm5fWbhThmIQYwjhk0llx0\nLLP0XhjLdJqlWGD24mlGlotm7fUynuk2a/HA5GL6kXE3uER3AmclOTPJicCVwI4J90nSymQ+kjQN\nzEWSpoG5SNJRpvrIpap6Nsl7gFvpLnG5rar2TLhbklYg85GkaWAukjQNzEWS5prqwSWAqtoJ7BzS\n5kZ2iLhtT237tr2y2h6pIeejhczK6zcLccxCDGAcM2dMuehYZum9MJbpNEuxwOzFA4w0F83a62U8\n023W4oEJxZSqmkS7kiRJkiRJmgHTPueSJEmSJEmSptjMDS4lOSXJriR72/3qBeptbHX2Jtk4z/Id\nSe4bZ9tJvpDka0n2JPl4khPG0XaSFyf5XJK/aW1fO+a4P5TkoSRPL6HNS5M8kGRfki3zLD8pyU1t\n+R1J1vcs+41W/kCSS5YS6yBtJzk1yReTPJ3k95ba7oBtvyXJXUnubfdvGmPb5ye5u92+luRnltr2\nLJlkjhqmSeacYZhkDhmmSeaEYRrk/WjLz2i59dfG1edZNyu5qvVhWeer1o+ZyFmtPzORt1qfzF19\nWsL38gtJvp3kT+eUn9le033tNT5xPD2f36A5M8mX2mfpyG/mV46v90f1b2ZyDQyUb9Yn+bue9+Pj\n4+77fBYRz08m+UqSZ5O8bc6yY/69Hoqqmqkb8BFgS3u8BfjwPHVOAfa3+9Xt8eqe5T8LfAq4b5xt\nAy9v9wE+A1w5jraBFwNvbHVOBP4SeOsY474QOA14epHtnQA8CLy69fdrwNlz6lwNfLw9vhK4qT0+\nu9U/CTizbeeEJcQ6SNsvAV4PvBv4vT4+24O0/Rrgn7TH5wKHxtj2i4FV7fFpwKNHnq/E26Dfl7a8\nrxw1LXEwYM4ZQt8nlkOmKI6BcsK0xNGz/NPAHwO/Nqk4Zu02K7lq0Fgmna9auzORs4YQy9TkrUFj\n6Vm+YnPXYr6XbdlFwE8Dfzqn/GbavhLwceA/Tns8x8qZwJeADROOYWZyzRDiWc+E/3b1Gc964F8C\nNwBvW8xnb5i3mTtyCbgc2N4ebweumKfOJcCuqjpcVU8Au4BLAZK8FPjPwAfH3XZVPdnqrKL7wCxl\nQqy+266qZ6rqi60Pfw98BVg3jrZbm7dX1cNLaO98YF9V7W/9vbH1YaE+fRq4KEla+Y1V9f2q+gaw\nr21v5G1X1Xer6svA95bQ3rDa/mpV/W0r3wO8KMlJY2r7map6tpW/kKV9rmfRJHPUME0y5wxqkjlk\nmCaZE4ZpkPeDJFcA36CLQ8MzK7kKlne+gtnJWTA7eQvMXYNazPeSqroNeKq3rL2Gb6J7TY+5/hgN\nlDOnxCzlGhjwOzqFjhtPVR2oqnuAH8xZdyyfvVkcXFrbM1DxLWDtPHVeBTzU8/xgKwP4APBbwDMT\naJskt9Id2fEUzyXMsbTd2j+Z7r8Dt4277SVYzLZ+WKcNbHwHOHUI/Rik7UENq+2fA75SVd8fV9tJ\nLkiyB7gXeHfPYNNKNMkcNUyTzDmDmmQOGaZJ5oRh6juONoDx68B/G0M/V5pZyVWwvPMVzE7OgtnJ\nW2DuGtRivpcLORX4ds/vyUl/rmE4eeZ/tVOw/uuEBjhmKdfA4PnmzCRfTfJ/kvybUXd2EQZ5jcfy\n/qwa9gbHIcmfA/94nkXv7X1SVZVk0UdJJDkP+KdV9Z/mnhM96rZ71rskyQuBT9KNyO8aV9tJVgF/\nBFxXVfvnLBtp2xqPJOcAHwYuHme7VXUHcE6SfwFsT/L5qur3CK6pN8kcNUyTzDkaj0nlhCG6Bvid\nqnp6ev/ROL1mJVe1Ns1XK8QM5C1YIblr1vYfRhzPv6uqQ0leRjc9yjvoTm3SZDwMnFFVjyd5HfC/\nk5xTz51ppHksy8GlqnrzQsuSPJLktKp6OMmR+V3mOgS8oef5OrrzXP81sCHJAbrX5pVJvlRVP6w7\nwrZ74/teks/SHea2q6d81G1vBfZW1e/OXXEccS/BIeD0Ods6tECdg+0H4T8CHl/kuqNqe1ADtZ1k\nHXALcFVVPTjOto+oqvvTTdx+LrB7iX1YNiaZo4ZpkjlnxCaZQ4ZpkjlhmAaJ4wLgbUk+ApwM/CDJ\n96qqr4smrDSzkqtgpvMVzE7OgtnJW2DuOq4hfC8X8jhwcpJV7WiTsXyuR5lnqupQu38qyafoToEa\n9+DSLOUaGCCeqirg+wBVdVeSB4EfY7L7L4O8xsPcF19YTcHkVMO8Af+doydT+8g8dU6hO8d5dbt9\nAzhlTp31LH1C777bBl4KnNbqrAJuAt4zrrjp5kT4DPAjE3zNFzuh9yq6ScjO5LnJzM6ZU2czR0/O\ndnN7fA5HTza3n6VN6N132z3Lf4H+JvQeJO6TW/2f7fN7NUjbZ/LchN4/Cvwt8Ip++jELtyF+X9Yz\n2Qm9J5ZzhtD3ieWQKYpjoJwwLXHMqXMNK3BS3BG+LzORq4YRyyTzVWt/JnLWEGKZmrw1aCxz6qzI\n3LWY72VP3Tfw/Am9/5ijJ/S+etrjWSjPtM/SK1qdF9BNjfLuCcQwM7lmCPGsOdJ/ugm0DzHn79s0\nxtNT93qeP6H3Mf9eD6WPk3yBRvSin0p3Lvxe4M957ofBBuATPfV+kW6isX3AO+fZznqWPrjUd9t0\n5+XeCdwD3Af8D5ZwRa0B215HN8ny/cDd7fbvx/Wa011d4SDdxGMHgWsW0eZlwP+lmzH/va3s/cC/\nbY9fSPdHZx/w18Cre9Z9b1vvAfq44suAbR8ADgNPt1jPHkfbwG8C3+15f+8GXjmmtt9BN1nl3XQT\noV4xiu/+crkN+n3pWb6eyQ4uTSznDKn/E8sh0xDHMHLCNMQxZxvXsAJ30Eb4nsxErho0lmnIV60f\nM5GzBoll2vLWoO9LzzZWZO5awvfyL4HHgL+j++18SSt/dXtN97XX+KRlEs98eeYlwF10+4F7gI8y\nuX9czUyuGSQeunndevdffnrSsSwynn/VviffpTuibM+xPnvDvqU1JEmSJEmSJC3ZLF4tTpIkSZIk\nSWPi4JIkSZIkSZL65uCSJEmSJEmS+ubgkiRJkiRJkvrm4JIkSZIkSZL65uCSJEmSJEmS+ubgkiRJ\nkiRJkvrm4JIkSZIkSZL69v8BpvOCrHkvKdcAAAAASUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 1440x360 with 4 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3oAAAE/CAYAAAAQWbGOAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nXsdp+V8EAAAAAElFTkSuQmCC\n",
            "text/plain": [
              "<Figure size 1080x360 with 3 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "i6KcQVXbIyq6"
      },
      "source": [
        "## 2. Optimization\n",
        "\n",
        "### (Informal) definition\n",
        "\n",
        "**Optimization**: Minimize (or maximize) some quantity.\n",
        "\n",
        "Applications:\n",
        "* Engineering: Minimize fuel consumption of an automobile\n",
        "* Economics: Maximize returns on an investment\n",
        "* Supply Chain Logistics: Minimize time taken to fulfill an order\n",
        "* Life: Maximize happiness\n"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "tP1NXcJHJh4X"
      },
      "source": [
        "### Formal definition \n",
        "* **Goal**: Find $\\theta^* = \\arg \\min_{\\theta} f(\\theta)$\n",
        "* **Optimization variable**: $\\theta \\in \\mathbb{R}^n$\n",
        "* **Objective function**: $f : \\mathbb{R}^n \\rightarrow \\mathbb{R}$\n",
        "* Note: Maximizing $f$ is equivalent to minimizing $-f$"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "f_B7xJTUKIO7"
      },
      "source": [
        "### Optimization for Machine Learning\n",
        "\n",
        "* Given a training set: $\\{(x_1, y_1),...,(x_n, y_n)\\}$\n",
        "* Prediction function: $h(x; \\theta)$\n",
        "* Define a loss function: $\\mathcal{L}(h(x; \\theta), y)$\n",
        "* Find the parameters: $\\theta = (\\theta_1, ..., \\theta_k)$ which minimizes the **empirical risk** $R(\\theta)$:\n",
        "$$\\min_\\theta R(\\theta) = \\min_\\theta \\frac{1}{n} \\sum_i^{n} \\mathcal{L}(h(x_i;\\theta), y_i)$$\n",
        "* The optimum satisfies:\n",
        "  - $\\nabla R(\\theta^*) = 0$\n",
        "  where $\\nabla R(\\theta) = \\big( \\frac{\\partial R}{\\partial \\theta_1}, \\frac{\\partial R}{\\partial \\theta_2}, ..., \\frac{\\partial R}{\\partial \\theta_k}\\big)$\n",
        "* Sometimes the equation has closed-form solution (e.g. linear regression)"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "rCD_nmErLbsi"
      },
      "source": [
        "### Gradient Descent Algorithms\n",
        "We want to minimize the objective function:\n",
        "$$R(\\theta) = \\frac{1}{n} \\sum_i^{n} f_i (\\theta) = \\frac{1}{n} \\sum_i^{n} \\mathcal{L}(h(x_i;\\theta), y_i)$$"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "WhSrofKogKJ7"
      },
      "source": [
        "### **Batch** gradient descent algorithm\n",
        "* Initialize the parameters randomly\n",
        "* For each iteration, do until convergence:\n",
        "$$ \\theta^{(k+1)} = \\theta^{(k)} - \\eta \\nabla R(\\theta^{(k)}) $$\n",
        "\n",
        "Note: $\\eta \\in \\mathbb{R}^+$ is the learning rate (a small step)\n",
        "\n",
        "Geometric interpretation:\n",
        "* Gradient is perpendicular to the tangent of the level set curve\n",
        "* Given the current point, negative gradient direction decreases the function fastest\n",
        "\n",
        "Alterative interpretation\n",
        "* Minimizing the first-order taylor approx of $f$ keep the new point close to the current point\n",
        "$$f(x^t) + \\nabla f(x^t)^\\intercal (x - x^t) + \\frac{1}{2\\eta} ||x - x^t||_2 ^2$$\n",
        "\n",
        "<!-- HC TODO: Insert learning rate diagram-->\n",
        "\n",
        "Convergence criteria\n",
        "* Change in objective function is close to zero\n",
        "* Gradient norm is close to zero\n",
        "* Validation error starts to increase (early-stopping)"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "0qy-Gh6XgSV6"
      },
      "source": [
        "### **Stochastic** Gradient Descent Algorithm\n",
        "* Initialize the parameters randomly\n",
        "* For each iteration, do until convergence:\n",
        "  - Randomly select a training sample $i$ (or a small subset of the training samples)\n",
        "  - Conduct gradient descent:\n",
        "    $$ \\theta^{(k+1)} = \\theta^{(k)} - \\eta \\nabla f_i(\\theta^{(k)}) $$\n",
        "\n",
        "**Intuition**: A noisy approximation of the gradient of the whole dataset\n",
        "\n",
        "**Pro**: each update requires a small amount of training data, good for training algorithms for a large-scale dataset\n",
        "\n",
        "**Tips**:\n",
        "* Subsample *without* replacement so that you visit each point on each pass through the dataset (\"epoch\")\n",
        "* Divide the log-likelihood estimate by the size of mini-batches, making learning rate invariant to the mini-batch size.\n"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "CgJ6_vvGg7c2"
      },
      "source": [
        "sgd_optimizer = torch.optim.SGD(model.parameters(), lr=0.01)"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "XyFAPQ5EgXKf"
      },
      "source": [
        "### Gradient Descent with Momentum\n",
        "* Initialize the parameters randomly\n",
        "* For each iteration, do until convergence:\n",
        "  - Update the momentum\n",
        "  $$\\delta^{(k+1)} = - \\eta \\nabla R(\\theta^{(k)}) + \\alpha \\delta^{(k)}$$\n",
        "  - Conduct gradient descent:\n",
        "    $$ \\theta^{(k+1)} = \\theta^{(k)} + \\delta^{(k+1)} $$\n",
        "\n",
        "**Pro**: \"accelerate\" learning by accumulating some \"velocity/momentum\" using the past gradients\n"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "m1x-gl68hkLH"
      },
      "source": [
        "# Set momentum parameter (alpha above)sgdm_optimizer = torch.optim.SGD(model.parameters(), lr=0.01, momentum=0.9)\n"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "mrL49i4vgZbP"
      },
      "source": [
        "### Nesterov Accelerated Gradient\n",
        "* Initialize the parameters randomly\n",
        "* For each iteration, do until convergence:\n",
        "  - Update the momentum\n",
        "  $$\\delta^{(k+1)} = - \\eta \\nabla R(\\theta^{(k)} + \\alpha \\delta^{(k)}) + \\alpha \\delta^{(k)} $$\n",
        "  - Conduct gradient descent:\n",
        "    $$ \\theta^{(k+1)} = \\theta^{(k)} + \\delta^{(k+1)} $$\n",
        "\n",
        "**Intuition**: Look into the future to see how much momentum is required.\n",
        "* First make a big jump in the direction of the previous accumulated gradient\n",
        "* Then measure the gradient where you end up and make a correction \n",
        "\n",
        "<!-- HC TODO: Add diagram for nesterov -->"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "jG7LzJKBhp2h"
      },
      "source": [
        "# Set momentum parameter (alpha above)\n",
        "nesterov_optimizer = torch.optim.SGD(model.parameters(), lr=0.01, momentum=0.9, nesterov=True)"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "Dkjijkn6gb3T"
      },
      "source": [
        "### Learning Rate Schedulers: Adagrad\n",
        "* Initialize the parameters randomly\n",
        "* For each iteration, do until convergence:\n",
        "  - Conduct gradient descent for the i-th parameter\n",
        "  $$ \\theta^{(k+1),i} = \\theta^{(k,i)} + \\frac{\\eta}{\\sqrt{G^{(k,i)} + \\epsilon}} \\cdot \\nabla R(\\theta^{(k,i)}) $$\n",
        "  $$ G^{(k,i)} = G^{(k-1,i)} + (\\nabla R(\\theta^{(k,i)}))^2 $$\n",
        "\n",
        "**Intuition**: It increases the learning rate for more sparse features and decreases the learning rate for less sparse ones, according to the history of the gradient"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "OfJwOZB0h8Pc"
      },
      "source": [
        "adagrad_optimizer = torch.optim.Adagrad(model.parameters(), lr=0.01)"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "xLOxnqOUgd4L"
      },
      "source": [
        "### Learning Rate Schedulers: RMSprop/Adadelta\n",
        "* Initialize the parameters randomly. $\\gamma$ is usually set to 0.9\n",
        "* For each iteration, do until convergence:\n",
        "  - Conduct gradient descent for the i-th parameter\n",
        "  $$ \\theta^{(k+1),i} = \\theta^{(k,i)} + \\frac{\\eta}{\\sqrt{G^{(k,i)} + \\epsilon}} \\cdot \\nabla R(\\theta^{(k,i)}) $$\n",
        "  $$ G^{(k,i)} = \\gamma G^{(k-1,i)} + (1-\\gamma)(\\nabla R(\\theta^{(k,i)}))^2 $$\n",
        "\n",
        "**Intuition**: Unlike Adagrad, the denominator places a significant weight on the most recent gradient. This also helps avoid decreasing learning rate too much."
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "qzQeNJfRiB3l"
      },
      "source": [
        "# alpha is the gamma parameter above\n",
        "rmsprop_optimizer = torch.optim.RMSprop(model.parameters(), lr=0.01, alpha=0.99)"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "wjU1G2Mdgf8a"
      },
      "source": [
        "### Learning Rate Schedulers: Adam\n",
        "* Initialize the parameters randomly.\n",
        "* For each iteration, do until convergence:\n",
        "  - Conduct gradient descent for the i-th parameter\n",
        "  $$ \\theta^{(k+1),i} = \\theta^{(k,i)} + \\frac{\\eta \\cdot \\hat{m}^{(k,i)}}{\\sqrt{\\hat{G}^{(k,i)} + \\epsilon}} \\cdot \\nabla R(\\theta^{(k,i)}) $$\n",
        "  $$ G^{(k,i)} = \\gamma G^{(k-1,i)} + (1-\\gamma)(\\nabla R(\\theta^{(k,i)}))^2 $$\n",
        "  $$ m^{(k,i)} = \\alpha m^{(k-1,i)} + (1-\\alpha)\\nabla R(\\theta^{(k,i)}) $$\n",
        "  - $\\hat{m}^{(k,i)}, \\hat{G}^{(k,i)}$ are bias corrected forms of ${m}^{(k,i)}, {G}^{(k,i)}$, respectively\n",
        "\n",
        "**Note**: Adam is co-authored by Professor Jimmy Ba!\n"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "0H84sZ9mdUQn"
      },
      "source": [
        "# betas correspond to alpha and gamma above\n",
        "adam_optimizer = torch.optim.Adam(model.parameters(), lr=0.01, betas=(0.9, 0.999))"
      ],
      "execution_count": null,
      "outputs": []
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "wJt8ZGJ9jDZz"
      },
      "source": [
        "### Summary: Optimizer algorithms\n",
        "\n",
        "Method  | Equations\n",
        "---|---\n",
        "Gradient Descent (GD) | $$\\theta^{(k+1)} = \\theta^{(k)} - \\eta \\nabla f_i(\\theta^{(k)}) $$|\n",
        "GD with Momentum | $\\delta^{(k+1)} = - \\eta \\nabla R(\\theta^{(k)} + \\alpha \\delta^{(k)}$<br> $\\theta^{(k+1)} = \\theta^{(k)} + \\delta^{(k+1)}$ | \n",
        "GD with Nesterov Momentum | $\\delta^{(k+1)} = - \\eta \\nabla R(\\theta^{(k)} + \\alpha \\delta^{(k)}) + \\alpha \\delta^{(k)} $<br> $\\theta^{(k+1)} = \\theta^{(k)} + \\delta^{(k+1)}$ | \n",
        "Adagrad |$$ \\theta^{(k+1),i} = \\theta^{(k,i)} + \\frac{\\eta}{\\sqrt{G^{(k,i)} + \\epsilon}} \\cdot \\nabla R(\\theta^{(k,i)}) $$ <br> $$ G^{(k,i)} = G^{(k-1,i)} + (\\nabla R(\\theta^{(k,i)}))^2 $$ |\n",
        "RMSProp |$$ \\theta^{(k+1),i} = \\theta^{(k,i)} + \\frac{\\eta}{\\sqrt{G^{(k,i)} + \\epsilon}} \\cdot \\nabla R(\\theta^{(k,i)}) $$ <br> $$ G^{(k,i)} = \\gamma G^{(k-1,i)} + (1-\\gamma)(\\nabla R(\\theta^{(k,i)}))^2 $$ |\n",
        "Adam    |$$ \\theta^{(k+1),i} = \\theta^{(k,i)} + \\frac{\\eta \\cdot \\hat{m}^((k,i)}{\\sqrt{\\hat{G}^{(k,i)} + \\epsilon}} \\cdot \\nabla R(\\theta^{(k,i)}) $$ <br> $$ G^{(k,i)} = \\gamma G^{(k-1,i)} + (1-\\gamma)(\\nabla R(\\theta^{(k,i)}))^2 $$ <br> $$ m^{(k,i)} = \\alpha m^{(k-1,i)} + (1-\\alpha)\\nabla R(\\theta^{(k,i)}) $$ |\n"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "bx8-ls3r5Czf",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 1000
        },
        "outputId": "7e3b556d-0ec5-4d21-af29-0fb587f418d0"
      },
      "source": [
        "# Instantiate a neural net model\n",
        "activation_func = torch.relu\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Create optimizers\n",
        "sgd_optimizer = torch.optim.SGD(model.parameters(), lr=0.01)\n",
        "sgdm_optimizer = torch.optim.SGD(model.parameters(), lr=0.01, momentum=0.9)\n",
        "nesterov_optimizer = torch.optim.SGD(model.parameters(), lr=0.01, momentum=0.9, nesterov=True)\n",
        "rmsprop_optimizer = torch.optim.RMSprop(model.parameters(), lr=0.001, alpha=0.99)\n",
        "adam_optimizer = torch.optim.Adam(model.parameters(), lr=0.001, betas=(0.9, 0.999))\n",
        "opt_list = [sgd_optimizer, sgdm_optimizer, nesterov_optimizer, rmsprop_optimizer, adam_optimizer]\n",
        "\n",
        "train_accs_list = []\n",
        "test_accs_list = []\n",
        "train_losses_list = []\n",
        "test_losses_list = []\n",
        "\n",
        "for opt in opt_list:\n",
        "  initialization='he'\n",
        "  model = apply_initialization(model, initialization)\n",
        "\n",
        "  # Define optimizer: Choose SGD for now\n",
        "  print(\"Optimizer: {}\".format(opt))\n",
        "\n",
        "  # Run the training loop \n",
        "  train_accs, test_accs, train_losses, test_losses = train_model(model, opt, train_dl, test_dl, epochs=10, print_every=2, debug=False)\n",
        "  train_accs_list.append(train_accs)\n",
        "  test_accs_list.append(test_accs)\n",
        "  train_losses_list.append(train_losses)\n",
        "  test_losses_list.append(test_losses)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "stream",
          "text": [
            "Optimizer: SGD (\n",
            "Parameter Group 0\n",
            "    dampening: 0\n",
            "    lr: 0.01\n",
            "    momentum: 0\n",
            "    nesterov: False\n",
            "    weight_decay: 0\n",
            ")\n",
            "Using cuda\n",
            "Epoch 0, Train acc: 86.27%, Test acc: 91.80%\n",
            "Epoch 2, Train acc: 94.77%, Test acc: 94.63%\n",
            "Epoch 4, Train acc: 96.20%, Test acc: 95.79%\n",
            "Epoch 6, Train acc: 96.98%, Test acc: 96.33%\n",
            "Epoch 8, Train acc: 97.52%, Test acc: 96.60%\n",
            "Optimizer: SGD (\n",
            "Parameter Group 0\n",
            "    dampening: 0\n",
            "    lr: 0.01\n",
            "    momentum: 0.9\n",
            "    nesterov: False\n",
            "    weight_decay: 0\n",
            ")\n",
            "Using cuda\n",
            "Epoch 0, Train acc: 91.40%, Test acc: 95.88%\n",
            "Epoch 2, Train acc: 98.20%, Test acc: 96.56%\n",
            "Epoch 4, Train acc: 99.31%, Test acc: 97.08%\n",
            "Epoch 6, Train acc: 99.83%, Test acc: 97.71%\n",
            "Epoch 8, Train acc: 99.94%, Test acc: 97.65%\n",
            "Optimizer: SGD (\n",
            "Parameter Group 0\n",
            "    dampening: 0\n",
            "    lr: 0.01\n",
            "    momentum: 0.9\n",
            "    nesterov: True\n",
            "    weight_decay: 0\n",
            ")\n",
            "Using cuda\n",
            "Epoch 0, Train acc: 92.28%, Test acc: 95.46%\n",
            "Epoch 2, Train acc: 98.23%, Test acc: 96.82%\n",
            "Epoch 4, Train acc: 99.36%, Test acc: 97.14%\n",
            "Epoch 6, Train acc: 99.79%, Test acc: 97.50%\n",
            "Epoch 8, Train acc: 99.95%, Test acc: 97.79%\n",
            "Optimizer: RMSprop (\n",
            "Parameter Group 0\n",
            "    alpha: 0.99\n",
            "    centered: False\n",
            "    eps: 1e-08\n",
            "    lr: 0.001\n",
            "    momentum: 0\n",
            "    weight_decay: 0\n",
            ")\n",
            "Using cuda\n",
            "Epoch 0, Train acc: 92.50%, Test acc: 91.48%\n",
            "Epoch 2, Train acc: 97.90%, Test acc: 96.98%\n",
            "Epoch 4, Train acc: 98.80%, Test acc: 96.93%\n",
            "Epoch 6, Train acc: 99.06%, Test acc: 95.81%\n",
            "Epoch 8, Train acc: 99.23%, Test acc: 97.58%\n",
            "Optimizer: Adam (\n",
            "Parameter Group 0\n",
            "    amsgrad: False\n",
            "    betas: (0.9, 0.999)\n",
            "    eps: 1e-08\n",
            "    lr: 0.001\n",
            "    weight_decay: 0\n",
            ")\n",
            "Using cuda\n",
            "Epoch 0, Train acc: 92.61%, Test acc: 96.17%\n",
            "Epoch 2, Train acc: 98.08%, Test acc: 96.66%\n",
            "Epoch 4, Train acc: 98.70%, Test acc: 97.11%\n",
            "Epoch 6, Train acc: 99.03%, Test acc: 97.65%\n",
            "Epoch 8, Train acc: 99.03%, Test acc: 97.66%\n"
          ],
          "name": "stdout"
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "5Zlb-RUxYk6L",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 590
        },
        "outputId": "7faf0206-5fbd-4185-fef9-87755e916810"
      },
      "source": [
        "# Visualize the loss / acc\n",
        "caption = \"Optimizers\"\n",
        "color_list = ['#1f77b4',\n",
        "              '#2ca02c',\n",
        "              '#d62728',\n",
        "              '#9467bd',\n",
        "              '#8c564b',\n",
        "              '#7f7f7f',\n",
        "              '#bcbd22'\n",
        "            ]\n",
        "idx = 0\n",
        "opt_name_list = [\"SGD\", \"Momentum\", \"Nesterov\", \"RMSProp\", \"Adam\"]\n",
        "for (opt_name, train_accs, test_accs) in zip(opt_name_list, train_accs_list, test_accs_list):\n",
        "  plt.plot(train_accs, label=\"train, {}\".format(opt_name), color=color_list[idx])\n",
        "  plt.plot(test_accs, label=\"test, {}\".format(opt_name), linestyle=\"--\", color=color_list[idx])\n",
        "  idx += 1\n",
        "plt.xlabel(\"Epoch\")\n",
        "plt.ylabel(\"Accuracy\")\n",
        "plt.legend()\n",
        "plt.title(\"Classification Accuracy vs Epoch: {}\".format(caption))\n",
        "\n",
        "\n",
        "# Visualize the loss / acc\n",
        "plt.figure()\n",
        "idx = 0\n",
        "for (opt_name, train_losses, test_losses) in zip(opt_name_list, train_losses_list, test_losses_list): \n",
        "  plt.plot(train_losses, label=\"train, {}\".format(opt_name), color=color_list[idx])\n",
        "  plt.plot(test_losses, label=\"test, {}\".format(opt_name), linestyle=\"--\", color=color_list[idx])\n",
        "  idx += 1\n",
        "plt.xlabel(\"Epoch\")\n",
        "plt.ylabel(\"Cross Entropy Loss\")\n",
        "plt.legend()\n",
        "plt.title(\"Cross Entropy Loss vs Epoch: {}\".format(caption))"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "execute_result",
          "data": {
            "text/plain": [
              "Text(0.5, 1.0, 'Cross Entropy Loss vs Epoch: Optimizers')"
            ]
          },
          "metadata": {
            "tags": []
          },
          "execution_count": 10
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYgAAAEWCAYAAAB8LwAVAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nn/wpZgAAAABJRU5ErkJggg==\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYIAAAEWCAYAAABrDZDcAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nrkJggg==\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "CtrLmITcNEoV"
      },
      "source": [
        "## Learning Rate\n",
        "<!-- HC TODO: Insert gradient descent diagram-->\n",
        "\n",
        "A good learning rate should be:\n",
        "* Should not be too big (objective will blow up)\n",
        "* Should not be too small (takes longer to convergent)\n"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "6FMwYDUY49pU"
      },
      "source": [
        "### Tuning Learning Rate\n",
        "\n",
        "Grid search\n",
        "* Optimize your model with a large learning rate (e.g. 0.1) and then progressively reduce this rate, often by an order of magnitude (0.1, 0.01, 0.001,...)\n",
        "* The idea is to find the highest stable learning rate\n",
        "\n",
        "Learning rate decay\n",
        "* Gradually reduce the learning rate after epochs\n",
        "  - **Step Decay**: reduce by factor every few epochs (e.g. a half every 5 epochs, or by 0.1 every 20 epochs), or when validation error stops improving\n",
        "  - **Exponential decay**: The learning rate at iteration $t$ is $\\eta(t)$, defined with hyperparameters $\\eta_0,k$:\n",
        "    $$\\eta(t) = \\eta_0 e^{-kt}$$\n",
        "  - **1/t decay**: Similar hyperparameters but with the following equation:\n",
        "    $$\\eta(t) = \\frac{\\eta_0}{1 + kt} $$\n",
        "* Intuition: supervision signal is strong at early stage and you don’t want to change too much after it’s learnt well\n",
        "\n",
        "\n",
        "\n",
        "Random Search\n",
        "* Argued by Bergstra and Bengio in [Random Search for Hyper-Parameter Optimization](http://www.jmlr.org/papers/volume13/bergstra12a/bergstra12a.pdf), \"Randomly chosen trials are more efficient for hyper parameter optimization than trials on a grid\"\n",
        "\n",
        "<!-- HC TODO: Insert random search vs grid search diagram -->\n",
        "\n"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "-J38jCKDRFoq"
      },
      "source": [
        "#### Experiment with different base learning rate"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "snCnYYMh5DkJ",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 374
        },
        "outputId": "355acc83-403c-487e-8258-df60c6a1c510"
      },
      "source": [
        "# Instantiate a neural net model\n",
        "activation_func = torch.relu\n",
        "model = MLP(activation_func=activation_func)\n",
        "\n",
        "# Apply initialization\n",
        "lr_list = [0.1, 0.01, 0.001]\n",
        "train_accs_list = []\n",
        "test_accs_list = []\n",
        "train_losses_list = []\n",
        "test_losses_list = []\n",
        "\n",
        "for lr in lr_list:\n",
        "  initialization='he'\n",
        "  model = apply_initialization(model, initialization)\n",
        "\n",
        "  # Define optimizer: Choose SGD for now\n",
        "  print(\"Learning rate: {}\".format(lr))\n",
        "  optimizer = torch.optim.SGD(model.parameters(), lr=lr, momentum=0.9)\n",
        "\n",
        "  # Run the training loop \n",
        "  train_accs, test_accs, train_losses, test_losses = train_model(model, optimizer, train_dl, test_dl, epochs=10, print_every=2, debug=False)\n",
        "  train_accs_list.append(train_accs)\n",
        "  test_accs_list.append(test_accs)\n",
        "  train_losses_list.append(train_losses)\n",
        "  test_losses_list.append(test_losses)"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "stream",
          "text": [
            "Learning rate: 0.1\n",
            "Using cuda\n",
            "Epoch 0, Train acc: 91.47%, Test acc: 93.80%\n",
            "Epoch 2, Train acc: 97.25%, Test acc: 96.65%\n",
            "Epoch 4, Train acc: 98.30%, Test acc: 97.42%\n",
            "Epoch 6, Train acc: 98.74%, Test acc: 96.98%\n",
            "Epoch 8, Train acc: 98.71%, Test acc: 97.00%\n",
            "Learning rate: 0.01\n",
            "Using cuda\n",
            "Epoch 0, Train acc: 91.54%, Test acc: 95.34%\n",
            "Epoch 2, Train acc: 98.14%, Test acc: 96.84%\n",
            "Epoch 4, Train acc: 99.29%, Test acc: 97.54%\n",
            "Epoch 6, Train acc: 99.78%, Test acc: 97.88%\n",
            "Epoch 8, Train acc: 99.94%, Test acc: 97.90%\n",
            "Learning rate: 0.001\n",
            "Using cuda\n",
            "Epoch 0, Train acc: 84.32%, Test acc: 92.21%\n",
            "Epoch 2, Train acc: 94.48%, Test acc: 94.77%\n",
            "Epoch 4, Train acc: 96.06%, Test acc: 95.87%\n",
            "Epoch 6, Train acc: 96.91%, Test acc: 96.30%\n",
            "Epoch 8, Train acc: 97.49%, Test acc: 96.66%\n"
          ],
          "name": "stdout"
        }
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "FdLTMuC6R3yr",
        "colab": {
          "base_uri": "https://localhost:8080/",
          "height": 590
        },
        "outputId": "16314393-14bb-414d-eb3d-f0146820fb2f"
      },
      "source": [
        "# Visualize the loss / acc\n",
        "caption = \"Learning Rates\"\n",
        "color_list = ['#1f77b4',\n",
        "              '#2ca02c',\n",
        "              '#d62728',\n",
        "              '#9467bd',\n",
        "              '#8c564b'\n",
        "            ]\n",
        "idx = 0\n",
        "for (lr, train_accs, test_accs) in zip(lr_list, train_accs_list, test_accs_list):\n",
        "  plt.plot(train_accs, label=\"train, lr={}\".format(lr), color=color_list[idx])\n",
        "  plt.plot(test_accs, label=\"test, lr={}\".format(lr), linestyle=\"--\", color=color_list[idx])\n",
        "  idx += 1\n",
        "plt.xlabel(\"Epoch\")\n",
        "plt.ylabel(\"Accuracy\")\n",
        "plt.legend()\n",
        "plt.title(\"Classification Accuracy vs Epoch: {}\".format(caption))\n",
        "\n",
        "\n",
        "# Visualize the loss / acc\n",
        "plt.figure()\n",
        "idx = 0\n",
        "for (lr, train_losses, test_losses) in zip(lr_list, train_losses_list, test_losses_list): \n",
        "  plt.plot(train_losses, label=\"train, lr={}\".format(lr), color=color_list[idx])\n",
        "  plt.plot(test_losses, label=\"test, lr={}\".format(lr), linestyle=\"--\", color=color_list[idx])\n",
        "  idx += 1\n",
        "plt.xlabel(\"Epoch\")\n",
        "plt.ylabel(\"Cross Entropy Loss\")\n",
        "plt.legend()\n",
        "plt.title(\"Cross Entropy Loss vs Epoch: {}\".format(caption))"
      ],
      "execution_count": null,
      "outputs": [
        {
          "output_type": "execute_result",
          "data": {
            "text/plain": [
              "Text(0.5, 1.0, 'Cross Entropy Loss vs Epoch: Learning Rates')"
            ]
          },
          "metadata": {
            "tags": []
          },
          "execution_count": 17
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYgAAAEWCAYAAAB8LwAVAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nU6n/D3LpBgc/E+QxAAAAAElFTkSuQmCC\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        },
        {
          "output_type": "display_data",
          "data": {
            "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYIAAAEWCAYAAABrDZDcAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nCYFCoVBMcf4/U1j5eJWrQ/EAAAAASUVORK5CYII=\n",
            "text/plain": [
              "<Figure size 432x288 with 1 Axes>"
            ]
          },
          "metadata": {
            "tags": []
          }
        }
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "-UTYawfnXv7D"
      },
      "source": [
        "Learning rate of 0.01 is the best among [0.1, 0.01, 0.001]"
      ]
    },
    {
      "cell_type": "markdown",
      "metadata": {
        "id": "7FATvS1KRLCH"
      },
      "source": [
        "#### Experiment with different learning rate decay"
      ]
    },
    {
      "cell_type": "code",
      "metadata": {
        "id": "SuHU2XoC5FTN"
      },
      "source": [
        "# TODO: Show different learning rate decay "
      ],
      "execution_count": null,
      "outputs": []
    }
  ]
}